# SPDX-License-Identifier: BSD-3-Clause
#
# Copyright 2020 Raritan Inc. All rights reserved.
#
# This is an auto-generated file.

#
# Section generated by IdlC from "UserEvent.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.idl


# value object
class UserEvent(raritan.rpc.idl.Event):
    idlType = "event.UserEvent:1.0.0"

    def __init__(self, actUserName, actIpAddr, source):
        super(raritan.rpc.event.UserEvent, self).__init__(source)
        typecheck.is_string(actUserName, AssertionError)
        typecheck.is_string(actIpAddr, AssertionError)

        self.actUserName = actUserName
        self.actIpAddr = actIpAddr

    def encode(self):
        json = super(raritan.rpc.event.UserEvent, self).encode()
        json['actUserName'] = self.actUserName
        json['actIpAddr'] = self.actIpAddr
        return json

    @classmethod
    def decode(cls, json, agent):
        obj = cls(
            actUserName = json['actUserName'],
            actIpAddr = json['actIpAddr'],
            # for idl.Event
            source = Interface.decode(json['source'], agent),
        )
        return obj

    def listElements(self):
        elements = ["actUserName", "actIpAddr"]
        elements = elements + super(raritan.rpc.event.UserEvent, self).listElements()
        return elements

#
# Section generated by IdlC from "DataPushService.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.event

import raritan.rpc.idl


# interface
class DataPushService(Interface):
    idlType = "event.DataPushService:1.0.1"

    # enumeration
    class EntryType(Enumeration):
        idlType = "event.DataPushService_1_0_1.EntryType:1.0.0"
        values = ["SENSORLIST", "SENSORLOG", "AMSLIST", "AMSLOG", "AUDITLOG"]

    EntryType.SENSORLIST = EntryType(0)
    EntryType.SENSORLOG = EntryType(1)
    EntryType.AMSLIST = EntryType(2)
    EntryType.AMSLOG = EntryType(3)
    EntryType.AUDITLOG = EntryType(4)

    ERR_NO_SUCH_ID = 1

    ERR_INVALID_PARAMS = 2

    ERR_MAX_ENTRIES_REACHED = 3

    # structure
    class EntrySettings(Structure):
        idlType = "event.DataPushService_1_0_1.EntrySettings:1.0.0"
        elements = ["url", "allowOffTimeRangeCerts", "caCertChain", "useAuth", "username", "password", "type", "items"]

        def __init__(self, url, allowOffTimeRangeCerts, caCertChain, useAuth, username, password, type, items):
            typecheck.is_string(url, AssertionError)
            typecheck.is_bool(allowOffTimeRangeCerts, AssertionError)
            typecheck.is_string(caCertChain, AssertionError)
            typecheck.is_bool(useAuth, AssertionError)
            typecheck.is_string(username, AssertionError)
            typecheck.is_string(password, AssertionError)
            typecheck.is_enum(type, raritan.rpc.event.DataPushService.EntryType, AssertionError)
            for x0 in items:
                typecheck.is_string(x0, AssertionError)

            self.url = url
            self.allowOffTimeRangeCerts = allowOffTimeRangeCerts
            self.caCertChain = caCertChain
            self.useAuth = useAuth
            self.username = username
            self.password = password
            self.type = type
            self.items = items

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                url = json['url'],
                allowOffTimeRangeCerts = json['allowOffTimeRangeCerts'],
                caCertChain = json['caCertChain'],
                useAuth = json['useAuth'],
                username = json['username'],
                password = json['password'],
                type = raritan.rpc.event.DataPushService.EntryType.decode(json['type']),
                items = [x0 for x0 in json['items']],
            )
            return obj

        def encode(self):
            json = {}
            json['url'] = self.url
            json['allowOffTimeRangeCerts'] = self.allowOffTimeRangeCerts
            json['caCertChain'] = self.caCertChain
            json['useAuth'] = self.useAuth
            json['username'] = self.username
            json['password'] = self.password
            json['type'] = raritan.rpc.event.DataPushService.EntryType.encode(self.type)
            json['items'] = [x0 for x0 in self.items]
            return json

    # structure
    class EntryStatus(Structure):
        idlType = "event.DataPushService_1_0_1.EntryStatus:1.0.0"
        elements = ["busy", "rescheduled", "lastAttemptTime", "lastSuccessTime"]

        def __init__(self, busy, rescheduled, lastAttemptTime, lastSuccessTime):
            typecheck.is_bool(busy, AssertionError)
            typecheck.is_bool(rescheduled, AssertionError)
            typecheck.is_time(lastAttemptTime, AssertionError)
            typecheck.is_time(lastSuccessTime, AssertionError)

            self.busy = busy
            self.rescheduled = rescheduled
            self.lastAttemptTime = lastAttemptTime
            self.lastSuccessTime = lastSuccessTime

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                busy = json['busy'],
                rescheduled = json['rescheduled'],
                lastAttemptTime = raritan.rpc.Time.decode(json['lastAttemptTime']),
                lastSuccessTime = raritan.rpc.Time.decode(json['lastSuccessTime']),
            )
            return obj

        def encode(self):
            json = {}
            json['busy'] = self.busy
            json['rescheduled'] = self.rescheduled
            json['lastAttemptTime'] = raritan.rpc.Time.encode(self.lastAttemptTime)
            json['lastSuccessTime'] = raritan.rpc.Time.encode(self.lastSuccessTime)
            return json

    # value object
    class EntryAddedEvent(UserEvent):
        idlType = "event.DataPushService_1_0_1.EntryAddedEvent:1.0.0"

        def __init__(self, entryId, settings, actUserName, actIpAddr, source):
            super(raritan.rpc.event.DataPushService.EntryAddedEvent, self).__init__(actUserName, actIpAddr, source)
            typecheck.is_int(entryId, AssertionError)
            typecheck.is_struct(settings, raritan.rpc.event.DataPushService.EntrySettings, AssertionError)

            self.entryId = entryId
            self.settings = settings

        def encode(self):
            json = super(raritan.rpc.event.DataPushService.EntryAddedEvent, self).encode()
            json['entryId'] = self.entryId
            json['settings'] = raritan.rpc.event.DataPushService.EntrySettings.encode(self.settings)
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                entryId = json['entryId'],
                settings = raritan.rpc.event.DataPushService.EntrySettings.decode(json['settings'], agent),
                # for event.UserEvent
                actUserName = json['actUserName'],
                actIpAddr = json['actIpAddr'],
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["entryId", "settings"]
            elements = elements + super(raritan.rpc.event.DataPushService.EntryAddedEvent, self).listElements()
            return elements

    # value object
    class EntryModifiedEvent(UserEvent):
        idlType = "event.DataPushService_1_0_1.EntryModifiedEvent:1.0.0"

        def __init__(self, entryId, oldSettings, newSettings, actUserName, actIpAddr, source):
            super(raritan.rpc.event.DataPushService.EntryModifiedEvent, self).__init__(actUserName, actIpAddr, source)
            typecheck.is_int(entryId, AssertionError)
            typecheck.is_struct(oldSettings, raritan.rpc.event.DataPushService.EntrySettings, AssertionError)
            typecheck.is_struct(newSettings, raritan.rpc.event.DataPushService.EntrySettings, AssertionError)

            self.entryId = entryId
            self.oldSettings = oldSettings
            self.newSettings = newSettings

        def encode(self):
            json = super(raritan.rpc.event.DataPushService.EntryModifiedEvent, self).encode()
            json['entryId'] = self.entryId
            json['oldSettings'] = raritan.rpc.event.DataPushService.EntrySettings.encode(self.oldSettings)
            json['newSettings'] = raritan.rpc.event.DataPushService.EntrySettings.encode(self.newSettings)
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                entryId = json['entryId'],
                oldSettings = raritan.rpc.event.DataPushService.EntrySettings.decode(json['oldSettings'], agent),
                newSettings = raritan.rpc.event.DataPushService.EntrySettings.decode(json['newSettings'], agent),
                # for event.UserEvent
                actUserName = json['actUserName'],
                actIpAddr = json['actIpAddr'],
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["entryId", "oldSettings", "newSettings"]
            elements = elements + super(raritan.rpc.event.DataPushService.EntryModifiedEvent, self).listElements()
            return elements

    # value object
    class EntryDeletedEvent(UserEvent):
        idlType = "event.DataPushService_1_0_1.EntryDeletedEvent:1.0.0"

        def __init__(self, entryId, actUserName, actIpAddr, source):
            super(raritan.rpc.event.DataPushService.EntryDeletedEvent, self).__init__(actUserName, actIpAddr, source)
            typecheck.is_int(entryId, AssertionError)

            self.entryId = entryId

        def encode(self):
            json = super(raritan.rpc.event.DataPushService.EntryDeletedEvent, self).encode()
            json['entryId'] = self.entryId
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                entryId = json['entryId'],
                # for event.UserEvent
                actUserName = json['actUserName'],
                actIpAddr = json['actIpAddr'],
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["entryId"]
            elements = elements + super(raritan.rpc.event.DataPushService.EntryDeletedEvent, self).listElements()
            return elements

    # value object
    class EntryStatusChangedEvent(raritan.rpc.idl.Event):
        idlType = "event.DataPushService_1_0_1.EntryStatusChangedEvent:1.0.0"

        def __init__(self, entryId, newStatus, source):
            super(raritan.rpc.event.DataPushService.EntryStatusChangedEvent, self).__init__(source)
            typecheck.is_int(entryId, AssertionError)
            typecheck.is_struct(newStatus, raritan.rpc.event.DataPushService.EntryStatus, AssertionError)

            self.entryId = entryId
            self.newStatus = newStatus

        def encode(self):
            json = super(raritan.rpc.event.DataPushService.EntryStatusChangedEvent, self).encode()
            json['entryId'] = self.entryId
            json['newStatus'] = raritan.rpc.event.DataPushService.EntryStatus.encode(self.newStatus)
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                entryId = json['entryId'],
                newStatus = raritan.rpc.event.DataPushService.EntryStatus.decode(json['newStatus'], agent),
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["entryId", "newStatus"]
            elements = elements + super(raritan.rpc.event.DataPushService.EntryStatusChangedEvent, self).listElements()
            return elements

    class _addEntry(Interface.Method):
        name = 'addEntry'

        @staticmethod
        def encode(entrySettings):
            typecheck.is_struct(entrySettings, raritan.rpc.event.DataPushService.EntrySettings, AssertionError)
            args = {}
            args['entrySettings'] = raritan.rpc.event.DataPushService.EntrySettings.encode(entrySettings)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            entryId = rsp['entryId']
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_int(entryId, DecodeException)
            return (_ret_, entryId)

    class _modifyEntry(Interface.Method):
        name = 'modifyEntry'

        @staticmethod
        def encode(entryId, entrySettings):
            typecheck.is_int(entryId, AssertionError)
            typecheck.is_struct(entrySettings, raritan.rpc.event.DataPushService.EntrySettings, AssertionError)
            args = {}
            args['entryId'] = entryId
            args['entrySettings'] = raritan.rpc.event.DataPushService.EntrySettings.encode(entrySettings)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _deleteEntry(Interface.Method):
        name = 'deleteEntry'

        @staticmethod
        def encode(entryId):
            typecheck.is_int(entryId, AssertionError)
            args = {}
            args['entryId'] = entryId
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _getEntry(Interface.Method):
        name = 'getEntry'

        @staticmethod
        def encode(entryId):
            typecheck.is_int(entryId, AssertionError)
            args = {}
            args['entryId'] = entryId
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            entrySettings = raritan.rpc.event.DataPushService.EntrySettings.decode(rsp['entrySettings'], agent)
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_struct(entrySettings, raritan.rpc.event.DataPushService.EntrySettings, DecodeException)
            return (_ret_, entrySettings)

    class _listEntries(Interface.Method):
        name = 'listEntries'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = dict([(
                elem['key'],
                raritan.rpc.event.DataPushService.EntrySettings.decode(elem['value'], agent))
                for elem in rsp['_ret_']])
            return _ret_

    class _pushData(Interface.Method):
        name = 'pushData'

        @staticmethod
        def encode(entryId):
            typecheck.is_int(entryId, AssertionError)
            args = {}
            args['entryId'] = entryId
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _getEntryStatus(Interface.Method):
        name = 'getEntryStatus'

        @staticmethod
        def encode(entryId):
            typecheck.is_int(entryId, AssertionError)
            args = {}
            args['entryId'] = entryId
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            entryStatus = raritan.rpc.event.DataPushService.EntryStatus.decode(rsp['entryStatus'], agent)
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_struct(entryStatus, raritan.rpc.event.DataPushService.EntryStatus, DecodeException)
            return (_ret_, entryStatus)
    def __init__(self, target, agent):
        super(DataPushService, self).__init__(target, agent)
        self.addEntry = DataPushService._addEntry(self)
        self.modifyEntry = DataPushService._modifyEntry(self)
        self.deleteEntry = DataPushService._deleteEntry(self)
        self.getEntry = DataPushService._getEntry(self)
        self.listEntries = DataPushService._listEntries(self)
        self.pushData = DataPushService._pushData(self)
        self.getEntryStatus = DataPushService._getEntryStatus(self)

#
# Section generated by IdlC from "AlarmManager.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.event

import raritan.rpc.idl


# interface
class AlarmManager(Interface):
    idlType = "event.AlarmManager:1.0.0"

    NO_ERROR = 0

    ERR_UNKNOWN_ALARM_ID = 1

    ERR_EXECUTING_ACTIONS = 2

    # structure
    class Alert(Structure):
        idlType = "event.AlarmManager.Alert:1.0.0"
        elements = ["eventCondition", "message", "firstAppearance", "lastAppearance", "numberAlerts"]

        def __init__(self, eventCondition, message, firstAppearance, lastAppearance, numberAlerts):
            typecheck.is_string(eventCondition, AssertionError)
            typecheck.is_string(message, AssertionError)
            typecheck.is_time(firstAppearance, AssertionError)
            typecheck.is_time(lastAppearance, AssertionError)
            typecheck.is_int(numberAlerts, AssertionError)

            self.eventCondition = eventCondition
            self.message = message
            self.firstAppearance = firstAppearance
            self.lastAppearance = lastAppearance
            self.numberAlerts = numberAlerts

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                eventCondition = json['eventCondition'],
                message = json['message'],
                firstAppearance = raritan.rpc.Time.decode(json['firstAppearance']),
                lastAppearance = raritan.rpc.Time.decode(json['lastAppearance']),
                numberAlerts = json['numberAlerts'],
            )
            return obj

        def encode(self):
            json = {}
            json['eventCondition'] = self.eventCondition
            json['message'] = self.message
            json['firstAppearance'] = raritan.rpc.Time.encode(self.firstAppearance)
            json['lastAppearance'] = raritan.rpc.Time.encode(self.lastAppearance)
            json['numberAlerts'] = self.numberAlerts
            return json

    # structure
    class Alarm(Structure):
        idlType = "event.AlarmManager.Alarm:1.0.0"
        elements = ["id", "name", "actionId", "alerts"]

        def __init__(self, id, name, actionId, alerts):
            typecheck.is_string(id, AssertionError)
            typecheck.is_string(name, AssertionError)
            typecheck.is_string(actionId, AssertionError)
            for x0 in alerts:
                typecheck.is_struct(x0, raritan.rpc.event.AlarmManager.Alert, AssertionError)

            self.id = id
            self.name = name
            self.actionId = actionId
            self.alerts = alerts

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                id = json['id'],
                name = json['name'],
                actionId = json['actionId'],
                alerts = [raritan.rpc.event.AlarmManager.Alert.decode(x0, agent) for x0 in json['alerts']],
            )
            return obj

        def encode(self):
            json = {}
            json['id'] = self.id
            json['name'] = self.name
            json['actionId'] = self.actionId
            json['alerts'] = [raritan.rpc.event.AlarmManager.Alert.encode(x0) for x0 in self.alerts]
            return json

    # value object
    class AlarmAddedEvent(raritan.rpc.idl.Event):
        idlType = "event.AlarmManager.AlarmAddedEvent:1.0.0"

        def __init__(self, alarm, source):
            super(raritan.rpc.event.AlarmManager.AlarmAddedEvent, self).__init__(source)
            typecheck.is_struct(alarm, raritan.rpc.event.AlarmManager.Alarm, AssertionError)

            self.alarm = alarm

        def encode(self):
            json = super(raritan.rpc.event.AlarmManager.AlarmAddedEvent, self).encode()
            json['alarm'] = raritan.rpc.event.AlarmManager.Alarm.encode(self.alarm)
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                alarm = raritan.rpc.event.AlarmManager.Alarm.decode(json['alarm'], agent),
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["alarm"]
            elements = elements + super(raritan.rpc.event.AlarmManager.AlarmAddedEvent, self).listElements()
            return elements

    # value object
    class AlarmUpdatedEvent(raritan.rpc.idl.Event):
        idlType = "event.AlarmManager.AlarmUpdatedEvent:1.0.0"

        def __init__(self, alarm, source):
            super(raritan.rpc.event.AlarmManager.AlarmUpdatedEvent, self).__init__(source)
            typecheck.is_struct(alarm, raritan.rpc.event.AlarmManager.Alarm, AssertionError)

            self.alarm = alarm

        def encode(self):
            json = super(raritan.rpc.event.AlarmManager.AlarmUpdatedEvent, self).encode()
            json['alarm'] = raritan.rpc.event.AlarmManager.Alarm.encode(self.alarm)
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                alarm = raritan.rpc.event.AlarmManager.Alarm.decode(json['alarm'], agent),
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["alarm"]
            elements = elements + super(raritan.rpc.event.AlarmManager.AlarmUpdatedEvent, self).listElements()
            return elements

    # value object
    class AlarmAcknowledgedEvent(raritan.rpc.idl.Event):
        idlType = "event.AlarmManager.AlarmAcknowledgedEvent:1.0.0"

        def __init__(self, alarmId, source):
            super(raritan.rpc.event.AlarmManager.AlarmAcknowledgedEvent, self).__init__(source)
            typecheck.is_string(alarmId, AssertionError)

            self.alarmId = alarmId

        def encode(self):
            json = super(raritan.rpc.event.AlarmManager.AlarmAcknowledgedEvent, self).encode()
            json['alarmId'] = self.alarmId
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                alarmId = json['alarmId'],
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["alarmId"]
            elements = elements + super(raritan.rpc.event.AlarmManager.AlarmAcknowledgedEvent, self).listElements()
            return elements

    class _acknowledgeAlarm(Interface.Method):
        name = 'acknowledgeAlarm'

        @staticmethod
        def encode(alarmId):
            typecheck.is_string(alarmId, AssertionError)
            args = {}
            args['alarmId'] = alarmId
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _listAlarms(Interface.Method):
        name = 'listAlarms'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = [raritan.rpc.event.AlarmManager.Alarm.decode(x0, agent) for x0 in rsp['_ret_']]
            for x0 in _ret_:
                typecheck.is_struct(x0, raritan.rpc.event.AlarmManager.Alarm, DecodeException)
            return _ret_
    def __init__(self, target, agent):
        super(AlarmManager, self).__init__(target, agent)
        self.acknowledgeAlarm = AlarmManager._acknowledgeAlarm(self)
        self.listAlarms = AlarmManager._listAlarms(self)

#
# Section generated by IdlC from "TimerEventManager.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.event


# interface
class TimerEventManager(Interface):
    idlType = "event.TimerEventManager:2.0.0"

    NO_ERROR = 0

    ERR_INVALID_SCHEDULE = 1

    ERR_UNKNOWN_EVENT_ID = 2

    ERR_CREATE_EVENT_ID_FAILED = 3

    ERR_MAX_TIMERS_CREATED = 4

    JAN = 1

    FEB = 2

    MAR = 3

    APR = 4

    MAY = 5

    JUN = 6

    JUL = 7

    AUG = 8

    SEP = 9

    OCT = 10

    NOV = 11

    DEC = 12

    SUN = 0

    MON = 1

    TUE = 2

    WED = 3

    THU = 4

    FRI = 5

    SAT = 6

    # structure
    class Range(Structure):
        idlType = "event.TimerEventManager_2_0_0.Range:1.0.0"
        elements = ["start", "end", "step"]

        def __init__(self, start, end, step):
            typecheck.is_int(start, AssertionError)
            typecheck.is_int(end, AssertionError)
            typecheck.is_int(step, AssertionError)

            self.start = start
            self.end = end
            self.step = step

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                start = json['start'],
                end = json['end'],
                step = json['step'],
            )
            return obj

        def encode(self):
            json = {}
            json['start'] = self.start
            json['end'] = self.end
            json['step'] = self.step
            return json

    # structure
    class Schedule(Structure):
        idlType = "event.TimerEventManager_2_0_0.Schedule:1.0.0"
        elements = ["enabled", "minute", "hour", "dayOfMonth", "month", "dayOfWeek"]

        def __init__(self, enabled, minute, hour, dayOfMonth, month, dayOfWeek):
            typecheck.is_bool(enabled, AssertionError)
            for x0 in minute:
                typecheck.is_struct(x0, raritan.rpc.event.TimerEventManager.Range, AssertionError)
            for x0 in hour:
                typecheck.is_struct(x0, raritan.rpc.event.TimerEventManager.Range, AssertionError)
            for x0 in dayOfMonth:
                typecheck.is_struct(x0, raritan.rpc.event.TimerEventManager.Range, AssertionError)
            for x0 in month:
                typecheck.is_struct(x0, raritan.rpc.event.TimerEventManager.Range, AssertionError)
            for x0 in dayOfWeek:
                typecheck.is_struct(x0, raritan.rpc.event.TimerEventManager.Range, AssertionError)

            self.enabled = enabled
            self.minute = minute
            self.hour = hour
            self.dayOfMonth = dayOfMonth
            self.month = month
            self.dayOfWeek = dayOfWeek

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                enabled = json['enabled'],
                minute = [raritan.rpc.event.TimerEventManager.Range.decode(x0, agent) for x0 in json['minute']],
                hour = [raritan.rpc.event.TimerEventManager.Range.decode(x0, agent) for x0 in json['hour']],
                dayOfMonth = [raritan.rpc.event.TimerEventManager.Range.decode(x0, agent) for x0 in json['dayOfMonth']],
                month = [raritan.rpc.event.TimerEventManager.Range.decode(x0, agent) for x0 in json['month']],
                dayOfWeek = [raritan.rpc.event.TimerEventManager.Range.decode(x0, agent) for x0 in json['dayOfWeek']],
            )
            return obj

        def encode(self):
            json = {}
            json['enabled'] = self.enabled
            json['minute'] = [raritan.rpc.event.TimerEventManager.Range.encode(x0) for x0 in self.minute]
            json['hour'] = [raritan.rpc.event.TimerEventManager.Range.encode(x0) for x0 in self.hour]
            json['dayOfMonth'] = [raritan.rpc.event.TimerEventManager.Range.encode(x0) for x0 in self.dayOfMonth]
            json['month'] = [raritan.rpc.event.TimerEventManager.Range.encode(x0) for x0 in self.month]
            json['dayOfWeek'] = [raritan.rpc.event.TimerEventManager.Range.encode(x0) for x0 in self.dayOfWeek]
            return json

    # structure
    class TimerEvent(Structure):
        idlType = "event.TimerEventManager_2_0_0.TimerEvent:1.0.0"
        elements = ["eventId", "executionTime"]

        def __init__(self, eventId, executionTime):
            for x0 in eventId:
                typecheck.is_string(x0, AssertionError)
            typecheck.is_struct(executionTime, raritan.rpc.event.TimerEventManager.Schedule, AssertionError)

            self.eventId = eventId
            self.executionTime = executionTime

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                eventId = [x0 for x0 in json['eventId']],
                executionTime = raritan.rpc.event.TimerEventManager.Schedule.decode(json['executionTime'], agent),
            )
            return obj

        def encode(self):
            json = {}
            json['eventId'] = [x0 for x0 in self.eventId]
            json['executionTime'] = raritan.rpc.event.TimerEventManager.Schedule.encode(self.executionTime)
            return json

    class _addTimerEvent(Interface.Method):
        name = 'addTimerEvent'

        @staticmethod
        def encode(schedule):
            typecheck.is_struct(schedule, raritan.rpc.event.TimerEventManager.Schedule, AssertionError)
            args = {}
            args['schedule'] = raritan.rpc.event.TimerEventManager.Schedule.encode(schedule)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            eventId = [x0 for x0 in rsp['eventId']]
            typecheck.is_int(_ret_, DecodeException)
            for x0 in eventId:
                typecheck.is_string(x0, DecodeException)
            return (_ret_, eventId)

    class _modifyTimerEvent(Interface.Method):
        name = 'modifyTimerEvent'

        @staticmethod
        def encode(eventId, schedule):
            for x0 in eventId:
                typecheck.is_string(x0, AssertionError)
            typecheck.is_struct(schedule, raritan.rpc.event.TimerEventManager.Schedule, AssertionError)
            args = {}
            args['eventId'] = [x0 for x0 in eventId]
            args['schedule'] = raritan.rpc.event.TimerEventManager.Schedule.encode(schedule)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _deleteTimerEvent(Interface.Method):
        name = 'deleteTimerEvent'

        @staticmethod
        def encode(eventId):
            for x0 in eventId:
                typecheck.is_string(x0, AssertionError)
            args = {}
            args['eventId'] = [x0 for x0 in eventId]
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _listTimerEvents(Interface.Method):
        name = 'listTimerEvents'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = [raritan.rpc.event.TimerEventManager.TimerEvent.decode(x0, agent) for x0 in rsp['_ret_']]
            for x0 in _ret_:
                typecheck.is_struct(x0, raritan.rpc.event.TimerEventManager.TimerEvent, DecodeException)
            return _ret_
    def __init__(self, target, agent):
        super(TimerEventManager, self).__init__(target, agent)
        self.addTimerEvent = TimerEventManager._addTimerEvent(self)
        self.modifyTimerEvent = TimerEventManager._modifyTimerEvent(self)
        self.deleteTimerEvent = TimerEventManager._deleteTimerEvent(self)
        self.listTimerEvents = TimerEventManager._listTimerEvents(self)

#
# Section generated by IdlC from "EventService.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.event

import raritan.rpc.idl


# interface
class Consumer(Interface):
    idlType = "event.Consumer:1.0.0"

    class _pushEvents(Interface.Method):
        name = 'pushEvents'

        @staticmethod
        def encode(events):
            for x0 in events:
                typecheck.is_valobj(x0, raritan.rpc.idl.Event, AssertionError)
            args = {}
            args['events'] = [ValueObject.encode(x0) for x0 in events]
            return args

        @staticmethod
        def decode(rsp, agent):
            return None
    def __init__(self, target, agent):
        super(Consumer, self).__init__(target, agent)
        self.pushEvents = Consumer._pushEvents(self)

# interface
class Channel(Interface):
    idlType = "event.Channel:1.0.1"

    class _demandEventType(Interface.Method):
        name = 'demandEventType'

        @staticmethod
        def encode(type):
            typecheck.is_typeinfo(type, AssertionError)
            args = {}
            args['type'] = raritan.rpc.TypeInfo.encode(type)
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _cancelEventType(Interface.Method):
        name = 'cancelEventType'

        @staticmethod
        def encode(type):
            typecheck.is_typeinfo(type, AssertionError)
            args = {}
            args['type'] = raritan.rpc.TypeInfo.encode(type)
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _demandEventTypes(Interface.Method):
        name = 'demandEventTypes'

        @staticmethod
        def encode(types):
            for x0 in types:
                typecheck.is_typeinfo(x0, AssertionError)
            args = {}
            args['types'] = [raritan.rpc.TypeInfo.encode(x0) for x0 in types]
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _cancelEventTypes(Interface.Method):
        name = 'cancelEventTypes'

        @staticmethod
        def encode(types):
            for x0 in types:
                typecheck.is_typeinfo(x0, AssertionError)
            args = {}
            args['types'] = [raritan.rpc.TypeInfo.encode(x0) for x0 in types]
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _demandEvent(Interface.Method):
        name = 'demandEvent'

        @staticmethod
        def encode(type, src):
            typecheck.is_typeinfo(type, AssertionError)
            typecheck.is_remote_obj(src, AssertionError)
            args = {}
            args['type'] = raritan.rpc.TypeInfo.encode(type)
            args['src'] = Interface.encode(src)
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _cancelEvent(Interface.Method):
        name = 'cancelEvent'

        @staticmethod
        def encode(type, src):
            typecheck.is_typeinfo(type, AssertionError)
            typecheck.is_remote_obj(src, AssertionError)
            args = {}
            args['type'] = raritan.rpc.TypeInfo.encode(type)
            args['src'] = Interface.encode(src)
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    # structure
    class EventSelect(Structure):
        idlType = "event.Channel_1_0_1.EventSelect:1.0.0"
        elements = ["type", "src"]

        def __init__(self, type, src):
            typecheck.is_typeinfo(type, AssertionError)
            typecheck.is_remote_obj(src, AssertionError)

            self.type = type
            self.src = src

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                type = raritan.rpc.TypeInfo.decode(json['type']),
                src = Interface.decode(json['src'], agent),
            )
            return obj

        def encode(self):
            json = {}
            json['type'] = raritan.rpc.TypeInfo.encode(self.type)
            json['src'] = Interface.encode(self.src)
            return json

    class _demandEvents(Interface.Method):
        name = 'demandEvents'

        @staticmethod
        def encode(events):
            for x0 in events:
                typecheck.is_struct(x0, raritan.rpc.event.Channel.EventSelect, AssertionError)
            args = {}
            args['events'] = [raritan.rpc.event.Channel.EventSelect.encode(x0) for x0 in events]
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _cancelEvents(Interface.Method):
        name = 'cancelEvents'

        @staticmethod
        def encode(events):
            for x0 in events:
                typecheck.is_struct(x0, raritan.rpc.event.Channel.EventSelect, AssertionError)
            args = {}
            args['events'] = [raritan.rpc.event.Channel.EventSelect.encode(x0) for x0 in events]
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _subscribe(Interface.Method):
        name = 'subscribe'

        @staticmethod
        def encode(consumer):
            typecheck.is_interface(consumer, raritan.rpc.event.Consumer, AssertionError)
            args = {}
            args['consumer'] = Interface.encode(consumer)
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _unsubscribe(Interface.Method):
        name = 'unsubscribe'

        @staticmethod
        def encode(consumer):
            typecheck.is_interface(consumer, raritan.rpc.event.Consumer, AssertionError)
            args = {}
            args['consumer'] = Interface.encode(consumer)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _pollEvents(Interface.Method):
        name = 'pollEvents'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            events = [ValueObject.decode(x0, agent) for x0 in rsp['events']]
            typecheck.is_bool(_ret_, DecodeException)
            for x0 in events:
                typecheck.is_valobj(x0, raritan.rpc.idl.Event, DecodeException)
            return (_ret_, events)

    class _pollEventsNb(Interface.Method):
        name = 'pollEventsNb'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            events = [ValueObject.decode(x0, agent) for x0 in rsp['events']]
            typecheck.is_bool(_ret_, DecodeException)
            for x0 in events:
                typecheck.is_valobj(x0, raritan.rpc.idl.Event, DecodeException)
            return (_ret_, events)
    def __init__(self, target, agent):
        super(Channel, self).__init__(target, agent)
        self.demandEventType = Channel._demandEventType(self)
        self.cancelEventType = Channel._cancelEventType(self)
        self.demandEventTypes = Channel._demandEventTypes(self)
        self.cancelEventTypes = Channel._cancelEventTypes(self)
        self.demandEvent = Channel._demandEvent(self)
        self.cancelEvent = Channel._cancelEvent(self)
        self.demandEvents = Channel._demandEvents(self)
        self.cancelEvents = Channel._cancelEvents(self)
        self.subscribe = Channel._subscribe(self)
        self.unsubscribe = Channel._unsubscribe(self)
        self.pollEvents = Channel._pollEvents(self)
        self.pollEventsNb = Channel._pollEventsNb(self)

# interface
class Service(Interface):
    idlType = "event.Service:1.0.1"

    INVALID_CHANNEL = 1

    class _createChannel(Interface.Method):
        name = 'createChannel'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = Interface.decode(rsp['_ret_'], agent)
            typecheck.is_interface(_ret_, raritan.rpc.event.Channel, DecodeException)
            return _ret_

    class _destroyChannel(Interface.Method):
        name = 'destroyChannel'

        @staticmethod
        def encode(channel):
            typecheck.is_interface(channel, raritan.rpc.event.Channel, AssertionError)
            args = {}
            args['channel'] = Interface.encode(channel)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _pushEvent(Interface.Method):
        name = 'pushEvent'

        @staticmethod
        def encode(event):
            typecheck.is_valobj(event, raritan.rpc.idl.Event, AssertionError)
            args = {}
            args['event'] = ValueObject.encode(event)
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _pushEvents(Interface.Method):
        name = 'pushEvents'

        @staticmethod
        def encode(events):
            for x0 in events:
                typecheck.is_valobj(x0, raritan.rpc.idl.Event, AssertionError)
            args = {}
            args['events'] = [ValueObject.encode(x0) for x0 in events]
            return args

        @staticmethod
        def decode(rsp, agent):
            return None
    def __init__(self, target, agent):
        super(Service, self).__init__(target, agent)
        self.createChannel = Service._createChannel(self)
        self.destroyChannel = Service._destroyChannel(self)
        self.pushEvent = Service._pushEvent(self)
        self.pushEvents = Service._pushEvents(self)

#
# Section generated by IdlC from "EventEngine.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.event


# structure
class KeyValue(Structure):
    idlType = "event.KeyValue:1.0.0"
    elements = ["key", "value"]

    def __init__(self, key, value):
        typecheck.is_string(key, AssertionError)
        typecheck.is_string(value, AssertionError)

        self.key = key
        self.value = value

    @classmethod
    def decode(cls, json, agent):
        obj = cls(
            key = json['key'],
            value = json['value'],
        )
        return obj

    def encode(self):
        json = {}
        json['key'] = self.key
        json['value'] = self.value
        return json

# structure
class Event(Structure):
    idlType = "event.Event:1.0.0"
    elements = ["type", "id", "asserted", "timeStamp", "context"]

    def __init__(self, type, id, asserted, timeStamp, context):
        typecheck.is_enum(type, raritan.rpc.event.Event.Type, AssertionError)
        for x0 in id:
            typecheck.is_string(x0, AssertionError)
        typecheck.is_bool(asserted, AssertionError)
        typecheck.is_time(timeStamp, AssertionError)
        for x0 in context:
            typecheck.is_struct(x0, raritan.rpc.event.KeyValue, AssertionError)

        self.type = type
        self.id = id
        self.asserted = asserted
        self.timeStamp = timeStamp
        self.context = context

    @classmethod
    def decode(cls, json, agent):
        obj = cls(
            type = raritan.rpc.event.Event.Type.decode(json['type']),
            id = [x0 for x0 in json['id']],
            asserted = json['asserted'],
            timeStamp = raritan.rpc.Time.decode(json['timeStamp']),
            context = [raritan.rpc.event.KeyValue.decode(x0, agent) for x0 in json['context']],
        )
        return obj

    def encode(self):
        json = {}
        json['type'] = raritan.rpc.event.Event.Type.encode(self.type)
        json['id'] = [x0 for x0 in self.id]
        json['asserted'] = self.asserted
        json['timeStamp'] = raritan.rpc.Time.encode(self.timeStamp)
        json['context'] = [raritan.rpc.event.KeyValue.encode(x0) for x0 in self.context]
        return json

    # enumeration
    class Type(Enumeration):
        idlType = "event.Event.Type:1.0.0"
        values = ["STATE", "TRIGGER"]

    Type.STATE = Type(0)
    Type.TRIGGER = Type(1)

# interface
class Engine(Interface):
    idlType = "event.Engine:1.0.1"

    # structure
    class EventDesc(Structure):
        idlType = "event.Engine_1_0_1.EventDesc:1.0.0"
        elements = ["eventDescType", "eventType", "dynNodeContext", "idComp", "name", "entries"]

        def __init__(self, eventDescType, eventType, dynNodeContext, idComp, name, entries):
            typecheck.is_enum(eventDescType, raritan.rpc.event.Engine.EventDesc.Type, AssertionError)
            typecheck.is_enum(eventType, raritan.rpc.event.Event.Type, AssertionError)
            typecheck.is_string(dynNodeContext, AssertionError)
            typecheck.is_string(idComp, AssertionError)
            typecheck.is_string(name, AssertionError)
            for x0 in entries:
                typecheck.is_struct(x0, raritan.rpc.event.Engine.EventDesc, AssertionError)

            self.eventDescType = eventDescType
            self.eventType = eventType
            self.dynNodeContext = dynNodeContext
            self.idComp = idComp
            self.name = name
            self.entries = entries

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                eventDescType = raritan.rpc.event.Engine.EventDesc.Type.decode(json['eventDescType']),
                eventType = raritan.rpc.event.Event.Type.decode(json['eventType']),
                dynNodeContext = json['dynNodeContext'],
                idComp = json['idComp'],
                name = json['name'],
                entries = [raritan.rpc.event.Engine.EventDesc.decode(x0, agent) for x0 in json['entries']],
            )
            return obj

        def encode(self):
            json = {}
            json['eventDescType'] = raritan.rpc.event.Engine.EventDesc.Type.encode(self.eventDescType)
            json['eventType'] = raritan.rpc.event.Event.Type.encode(self.eventType)
            json['dynNodeContext'] = self.dynNodeContext
            json['idComp'] = self.idComp
            json['name'] = self.name
            json['entries'] = [raritan.rpc.event.Engine.EventDesc.encode(x0) for x0 in self.entries]
            return json

        # enumeration
        class Type(Enumeration):
            idlType = "event.Engine_1_0_1.EventDesc.Type:1.0.0"
            values = ["NODE", "DYN_NODE", "LEAF"]

        Type.NODE = Type(0)
        Type.DYN_NODE = Type(1)
        Type.LEAF = Type(2)

    class _listEventDescs(Interface.Method):
        name = 'listEventDescs'

        @staticmethod
        def encode(eventIdPrefix):
            for x0 in eventIdPrefix:
                typecheck.is_string(x0, AssertionError)
            args = {}
            args['eventIdPrefix'] = [x0 for x0 in eventIdPrefix]
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            eventDescs = [raritan.rpc.event.Engine.EventDesc.decode(x0, agent) for x0 in rsp['eventDescs']]
            typecheck.is_int(_ret_, DecodeException)
            for x0 in eventDescs:
                typecheck.is_struct(x0, raritan.rpc.event.Engine.EventDesc, DecodeException)
            return (_ret_, eventDescs)

    class _listActionTypes(Interface.Method):
        name = 'listActionTypes'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = [x0 for x0 in rsp['_ret_']]
            for x0 in _ret_:
                typecheck.is_string(x0, DecodeException)
            return _ret_

    # structure
    class Action(Structure):
        idlType = "event.Engine_1_0_1.Action:1.0.0"
        elements = ["id", "name", "isSystem", "type", "arguments"]

        def __init__(self, id, name, isSystem, type, arguments):
            typecheck.is_string(id, AssertionError)
            typecheck.is_string(name, AssertionError)
            typecheck.is_bool(isSystem, AssertionError)
            typecheck.is_string(type, AssertionError)
            for x0 in arguments:
                typecheck.is_struct(x0, raritan.rpc.event.KeyValue, AssertionError)

            self.id = id
            self.name = name
            self.isSystem = isSystem
            self.type = type
            self.arguments = arguments

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                id = json['id'],
                name = json['name'],
                isSystem = json['isSystem'],
                type = json['type'],
                arguments = [raritan.rpc.event.KeyValue.decode(x0, agent) for x0 in json['arguments']],
            )
            return obj

        def encode(self):
            json = {}
            json['id'] = self.id
            json['name'] = self.name
            json['isSystem'] = self.isSystem
            json['type'] = self.type
            json['arguments'] = [raritan.rpc.event.KeyValue.encode(x0) for x0 in self.arguments]
            return json

    class _addAction(Interface.Method):
        name = 'addAction'

        @staticmethod
        def encode(action):
            typecheck.is_struct(action, raritan.rpc.event.Engine.Action, AssertionError)
            args = {}
            args['action'] = raritan.rpc.event.Engine.Action.encode(action)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            actionId = rsp['actionId']
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_string(actionId, DecodeException)
            return (_ret_, actionId)

    class _modifyAction(Interface.Method):
        name = 'modifyAction'

        @staticmethod
        def encode(action):
            typecheck.is_struct(action, raritan.rpc.event.Engine.Action, AssertionError)
            args = {}
            args['action'] = raritan.rpc.event.Engine.Action.encode(action)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _deleteAction(Interface.Method):
        name = 'deleteAction'

        @staticmethod
        def encode(actionId):
            typecheck.is_string(actionId, AssertionError)
            args = {}
            args['actionId'] = actionId
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _listActions(Interface.Method):
        name = 'listActions'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = [raritan.rpc.event.Engine.Action.decode(x0, agent) for x0 in rsp['_ret_']]
            for x0 in _ret_:
                typecheck.is_struct(x0, raritan.rpc.event.Engine.Action, DecodeException)
            return _ret_

    class _triggerAction(Interface.Method):
        name = 'triggerAction'

        @staticmethod
        def encode(actionId, context):
            typecheck.is_string(actionId, AssertionError)
            for x0 in context:
                typecheck.is_struct(x0, raritan.rpc.event.KeyValue, AssertionError)
            args = {}
            args['actionId'] = actionId
            args['context'] = [raritan.rpc.event.KeyValue.encode(x0) for x0 in context]
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            errMsg = rsp['errMsg']
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_string(errMsg, DecodeException)
            return (_ret_, errMsg)

    class _testAction(Interface.Method):
        name = 'testAction'

        @staticmethod
        def encode(action, context):
            typecheck.is_struct(action, raritan.rpc.event.Engine.Action, AssertionError)
            for x0 in context:
                typecheck.is_struct(x0, raritan.rpc.event.KeyValue, AssertionError)
            args = {}
            args['action'] = raritan.rpc.event.Engine.Action.encode(action)
            args['context'] = [raritan.rpc.event.KeyValue.encode(x0) for x0 in context]
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            errMsg = rsp['errMsg']
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_string(errMsg, DecodeException)
            return (_ret_, errMsg)

    # structure
    class Condition(Structure):
        idlType = "event.Engine_1_0_1.Condition:1.0.0"
        elements = ["negate", "operation", "matchType", "eventId", "conditions"]

        def __init__(self, negate, operation, matchType, eventId, conditions):
            typecheck.is_bool(negate, AssertionError)
            typecheck.is_enum(operation, raritan.rpc.event.Engine.Condition.Op, AssertionError)
            typecheck.is_enum(matchType, raritan.rpc.event.Engine.Condition.MatchType, AssertionError)
            for x0 in eventId:
                typecheck.is_string(x0, AssertionError)
            for x0 in conditions:
                typecheck.is_struct(x0, raritan.rpc.event.Engine.Condition, AssertionError)

            self.negate = negate
            self.operation = operation
            self.matchType = matchType
            self.eventId = eventId
            self.conditions = conditions

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                negate = json['negate'],
                operation = raritan.rpc.event.Engine.Condition.Op.decode(json['operation']),
                matchType = raritan.rpc.event.Engine.Condition.MatchType.decode(json['matchType']),
                eventId = [x0 for x0 in json['eventId']],
                conditions = [raritan.rpc.event.Engine.Condition.decode(x0, agent) for x0 in json['conditions']],
            )
            return obj

        def encode(self):
            json = {}
            json['negate'] = self.negate
            json['operation'] = raritan.rpc.event.Engine.Condition.Op.encode(self.operation)
            json['matchType'] = raritan.rpc.event.Engine.Condition.MatchType.encode(self.matchType)
            json['eventId'] = [x0 for x0 in self.eventId]
            json['conditions'] = [raritan.rpc.event.Engine.Condition.encode(x0) for x0 in self.conditions]
            return json

        # enumeration
        class Op(Enumeration):
            idlType = "event.Engine_1_0_1.Condition.Op:1.0.0"
            values = ["AND", "OR", "XOR"]

        Op.AND = Op(0)
        Op.OR = Op(1)
        Op.XOR = Op(2)

        # enumeration
        class MatchType(Enumeration):
            idlType = "event.Engine_1_0_1.Condition.MatchType:1.0.0"
            values = ["ASSERTED", "DEASSERTED", "BOTH"]

        MatchType.ASSERTED = MatchType(0)
        MatchType.DEASSERTED = MatchType(1)
        MatchType.BOTH = MatchType(2)

    # structure
    class Rule(Structure):
        idlType = "event.Engine_1_0_1.Rule:1.0.0"
        elements = ["id", "name", "isSystem", "isEnabled", "isAutoRearm", "hasMatched", "condition", "actionIds", "arguments"]

        def __init__(self, id, name, isSystem, isEnabled, isAutoRearm, hasMatched, condition, actionIds, arguments):
            typecheck.is_string(id, AssertionError)
            typecheck.is_string(name, AssertionError)
            typecheck.is_bool(isSystem, AssertionError)
            typecheck.is_bool(isEnabled, AssertionError)
            typecheck.is_bool(isAutoRearm, AssertionError)
            typecheck.is_bool(hasMatched, AssertionError)
            typecheck.is_struct(condition, raritan.rpc.event.Engine.Condition, AssertionError)
            for x0 in actionIds:
                typecheck.is_string(x0, AssertionError)
            for x0 in arguments:
                typecheck.is_struct(x0, raritan.rpc.event.KeyValue, AssertionError)

            self.id = id
            self.name = name
            self.isSystem = isSystem
            self.isEnabled = isEnabled
            self.isAutoRearm = isAutoRearm
            self.hasMatched = hasMatched
            self.condition = condition
            self.actionIds = actionIds
            self.arguments = arguments

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                id = json['id'],
                name = json['name'],
                isSystem = json['isSystem'],
                isEnabled = json['isEnabled'],
                isAutoRearm = json['isAutoRearm'],
                hasMatched = json['hasMatched'],
                condition = raritan.rpc.event.Engine.Condition.decode(json['condition'], agent),
                actionIds = [x0 for x0 in json['actionIds']],
                arguments = [raritan.rpc.event.KeyValue.decode(x0, agent) for x0 in json['arguments']],
            )
            return obj

        def encode(self):
            json = {}
            json['id'] = self.id
            json['name'] = self.name
            json['isSystem'] = self.isSystem
            json['isEnabled'] = self.isEnabled
            json['isAutoRearm'] = self.isAutoRearm
            json['hasMatched'] = self.hasMatched
            json['condition'] = raritan.rpc.event.Engine.Condition.encode(self.condition)
            json['actionIds'] = [x0 for x0 in self.actionIds]
            json['arguments'] = [raritan.rpc.event.KeyValue.encode(x0) for x0 in self.arguments]
            return json

    class _addRule(Interface.Method):
        name = 'addRule'

        @staticmethod
        def encode(rule):
            typecheck.is_struct(rule, raritan.rpc.event.Engine.Rule, AssertionError)
            args = {}
            args['rule'] = raritan.rpc.event.Engine.Rule.encode(rule)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            ruleId = rsp['ruleId']
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_string(ruleId, DecodeException)
            return (_ret_, ruleId)

    class _modifyRule(Interface.Method):
        name = 'modifyRule'

        @staticmethod
        def encode(rule):
            typecheck.is_struct(rule, raritan.rpc.event.Engine.Rule, AssertionError)
            args = {}
            args['rule'] = raritan.rpc.event.Engine.Rule.encode(rule)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _enableRule(Interface.Method):
        name = 'enableRule'

        @staticmethod
        def encode(ruleId):
            typecheck.is_string(ruleId, AssertionError)
            args = {}
            args['ruleId'] = ruleId
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _disableRule(Interface.Method):
        name = 'disableRule'

        @staticmethod
        def encode(ruleId):
            typecheck.is_string(ruleId, AssertionError)
            args = {}
            args['ruleId'] = ruleId
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _deleteRule(Interface.Method):
        name = 'deleteRule'

        @staticmethod
        def encode(ruleId):
            typecheck.is_string(ruleId, AssertionError)
            args = {}
            args['ruleId'] = ruleId
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _listRules(Interface.Method):
        name = 'listRules'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = [raritan.rpc.event.Engine.Rule.decode(x0, agent) for x0 in rsp['_ret_']]
            for x0 in _ret_:
                typecheck.is_struct(x0, raritan.rpc.event.Engine.Rule, DecodeException)
            return _ret_

    class _deliverEvent(Interface.Method):
        name = 'deliverEvent'

        @staticmethod
        def encode(event):
            typecheck.is_struct(event, raritan.rpc.event.Event, AssertionError)
            args = {}
            args['event'] = raritan.rpc.event.Event.encode(event)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _rearmRule(Interface.Method):
        name = 'rearmRule'

        @staticmethod
        def encode(ruleId):
            typecheck.is_string(ruleId, AssertionError)
            args = {}
            args['ruleId'] = ruleId
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_
    def __init__(self, target, agent):
        super(Engine, self).__init__(target, agent)
        self.listEventDescs = Engine._listEventDescs(self)
        self.listActionTypes = Engine._listActionTypes(self)
        self.addAction = Engine._addAction(self)
        self.modifyAction = Engine._modifyAction(self)
        self.deleteAction = Engine._deleteAction(self)
        self.listActions = Engine._listActions(self)
        self.triggerAction = Engine._triggerAction(self)
        self.testAction = Engine._testAction(self)
        self.addRule = Engine._addRule(self)
        self.modifyRule = Engine._modifyRule(self)
        self.enableRule = Engine._enableRule(self)
        self.disableRule = Engine._disableRule(self)
        self.deleteRule = Engine._deleteRule(self)
        self.listRules = Engine._listRules(self)
        self.deliverEvent = Engine._deliverEvent(self)
        self.rearmRule = Engine._rearmRule(self)



# SPDX-License-Identifier: BSD-3-Clause
#
# Copyright 2020 Raritan Inc. All rights reserved.
#
# This is an auto-generated file.

#
# Section generated by IdlC from "AnalogModem.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.idl

import raritan.rpc.serial


# interface
class AnalogModem(Interface):
    idlType = "serial.AnalogModem:1.0.0"

    SUCCESS = 0

    ERR_INVALID_VALUE = 1

    # structure
    class Settings(Structure):
        idlType = "serial.AnalogModem.Settings:1.0.0"
        elements = ["dialInEnabled", "ringsUntilAnswer"]

        def __init__(self, dialInEnabled, ringsUntilAnswer):
            typecheck.is_bool(dialInEnabled, AssertionError)
            typecheck.is_int(ringsUntilAnswer, AssertionError)

            self.dialInEnabled = dialInEnabled
            self.ringsUntilAnswer = ringsUntilAnswer

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                dialInEnabled = json['dialInEnabled'],
                ringsUntilAnswer = json['ringsUntilAnswer'],
            )
            return obj

        def encode(self):
            json = {}
            json['dialInEnabled'] = self.dialInEnabled
            json['ringsUntilAnswer'] = self.ringsUntilAnswer
            return json

    # value object
    class DialInEvent(raritan.rpc.idl.Event):
        idlType = "serial.AnalogModem.DialInEvent:1.0.0"

        def __init__(self, number, source):
            super(raritan.rpc.serial.AnalogModem.DialInEvent, self).__init__(source)
            typecheck.is_string(number, AssertionError)

            self.number = number

        def encode(self):
            json = super(raritan.rpc.serial.AnalogModem.DialInEvent, self).encode()
            json['number'] = self.number
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                number = json['number'],
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["number"]
            elements = elements + super(raritan.rpc.serial.AnalogModem.DialInEvent, self).listElements()
            return elements

    # value object
    class CallReceivedEvent(DialInEvent):
        idlType = "serial.AnalogModem.CallReceivedEvent:1.0.0"

        def __init__(self, number, source):
            super(raritan.rpc.serial.AnalogModem.CallReceivedEvent, self).__init__(number, source)

        def encode(self):
            json = super(raritan.rpc.serial.AnalogModem.CallReceivedEvent, self).encode()
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                # for serial.AnalogModem.DialInEvent
                number = json['number'],
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = []
            elements = elements + super(raritan.rpc.serial.AnalogModem.CallReceivedEvent, self).listElements()
            return elements

    # value object
    class CallEndedEvent(DialInEvent):
        idlType = "serial.AnalogModem.CallEndedEvent:1.0.0"

        def __init__(self, disconnectedRemotely, number, source):
            super(raritan.rpc.serial.AnalogModem.CallEndedEvent, self).__init__(number, source)
            typecheck.is_bool(disconnectedRemotely, AssertionError)

            self.disconnectedRemotely = disconnectedRemotely

        def encode(self):
            json = super(raritan.rpc.serial.AnalogModem.CallEndedEvent, self).encode()
            json['disconnectedRemotely'] = self.disconnectedRemotely
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                disconnectedRemotely = json['disconnectedRemotely'],
                # for serial.AnalogModem.DialInEvent
                number = json['number'],
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["disconnectedRemotely"]
            elements = elements + super(raritan.rpc.serial.AnalogModem.CallEndedEvent, self).listElements()
            return elements

    class _getSettings(Interface.Method):
        name = 'getSettings'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = raritan.rpc.serial.AnalogModem.Settings.decode(rsp['_ret_'], agent)
            typecheck.is_struct(_ret_, raritan.rpc.serial.AnalogModem.Settings, DecodeException)
            return _ret_

    class _setSettings(Interface.Method):
        name = 'setSettings'

        @staticmethod
        def encode(settings):
            typecheck.is_struct(settings, raritan.rpc.serial.AnalogModem.Settings, AssertionError)
            args = {}
            args['settings'] = raritan.rpc.serial.AnalogModem.Settings.encode(settings)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_
    def __init__(self, target, agent):
        super(AnalogModem, self).__init__(target, agent)
        self.getSettings = AnalogModem._getSettings(self)
        self.setSettings = AnalogModem._setSettings(self)

#
# Section generated by IdlC from "GsmModem.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.idl

import raritan.rpc.serial


# interface
class GsmModem(Interface):
    idlType = "serial.GsmModem:1.0.2"

    SUCCESS = 0

    ERR_INVALID_VALUE = 1

    ERR_WRONG_PIN = 2

    ERR_SMS_SEND_FAILED = 3

    ERR_COMMUNICATION_FAILURE = 4

    ERR_SIM_LOCKED = 5

    ERR_WRONG_SIM_STATUS = 6

    ERR_WRONG_PUK = 7

    ERR_SIM_PROBLEM = 8

    # enumeration
    class SimSecurityStatus(Enumeration):
        idlType = "serial.GsmModem_1_0_2.SimSecurityStatus:1.0.0"
        values = ["UNLOCKED", "WAITFORPIN", "WAITFORPUK", "UNKNOWN"]

    SimSecurityStatus.UNLOCKED = SimSecurityStatus(0)
    SimSecurityStatus.WAITFORPIN = SimSecurityStatus(1)
    SimSecurityStatus.WAITFORPUK = SimSecurityStatus(2)
    SimSecurityStatus.UNKNOWN = SimSecurityStatus(3)

    # structure
    class Settings(Structure):
        idlType = "serial.GsmModem_1_0_2.Settings:1.0.0"
        elements = ["pin", "smsc"]

        def __init__(self, pin, smsc):
            typecheck.is_string(pin, AssertionError)
            typecheck.is_string(smsc, AssertionError)

            self.pin = pin
            self.smsc = smsc

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                pin = json['pin'],
                smsc = json['smsc'],
            )
            return obj

        def encode(self):
            json = {}
            json['pin'] = self.pin
            json['smsc'] = self.smsc
            return json

    # structure
    class Information(Structure):
        idlType = "serial.GsmModem_1_0_2.Information:1.0.0"
        elements = ["imei", "imsi", "manufacturer", "model", "revision", "ownNumber", "simSmsc", "networkName", "serviceProviderName", "receptionLevel"]

        def __init__(self, imei, imsi, manufacturer, model, revision, ownNumber, simSmsc, networkName, serviceProviderName, receptionLevel):
            typecheck.is_string(imei, AssertionError)
            typecheck.is_string(imsi, AssertionError)
            typecheck.is_string(manufacturer, AssertionError)
            typecheck.is_string(model, AssertionError)
            typecheck.is_string(revision, AssertionError)
            typecheck.is_string(ownNumber, AssertionError)
            typecheck.is_string(simSmsc, AssertionError)
            typecheck.is_string(networkName, AssertionError)
            typecheck.is_string(serviceProviderName, AssertionError)
            typecheck.is_int(receptionLevel, AssertionError)

            self.imei = imei
            self.imsi = imsi
            self.manufacturer = manufacturer
            self.model = model
            self.revision = revision
            self.ownNumber = ownNumber
            self.simSmsc = simSmsc
            self.networkName = networkName
            self.serviceProviderName = serviceProviderName
            self.receptionLevel = receptionLevel

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                imei = json['imei'],
                imsi = json['imsi'],
                manufacturer = json['manufacturer'],
                model = json['model'],
                revision = json['revision'],
                ownNumber = json['ownNumber'],
                simSmsc = json['simSmsc'],
                networkName = json['networkName'],
                serviceProviderName = json['serviceProviderName'],
                receptionLevel = json['receptionLevel'],
            )
            return obj

        def encode(self):
            json = {}
            json['imei'] = self.imei
            json['imsi'] = self.imsi
            json['manufacturer'] = self.manufacturer
            json['model'] = self.model
            json['revision'] = self.revision
            json['ownNumber'] = self.ownNumber
            json['simSmsc'] = self.simSmsc
            json['networkName'] = self.networkName
            json['serviceProviderName'] = self.serviceProviderName
            json['receptionLevel'] = self.receptionLevel
            return json

    # value object
    class SimSecurityStatusChangedEvent(raritan.rpc.idl.Event):
        idlType = "serial.GsmModem_1_0_2.SimSecurityStatusChangedEvent:1.0.0"

        def __init__(self, newSimStatus, source):
            super(raritan.rpc.serial.GsmModem.SimSecurityStatusChangedEvent, self).__init__(source)
            typecheck.is_enum(newSimStatus, raritan.rpc.serial.GsmModem.SimSecurityStatus, AssertionError)

            self.newSimStatus = newSimStatus

        def encode(self):
            json = super(raritan.rpc.serial.GsmModem.SimSecurityStatusChangedEvent, self).encode()
            json['newSimStatus'] = raritan.rpc.serial.GsmModem.SimSecurityStatus.encode(self.newSimStatus)
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                newSimStatus = raritan.rpc.serial.GsmModem.SimSecurityStatus.decode(json['newSimStatus']),
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["newSimStatus"]
            elements = elements + super(raritan.rpc.serial.GsmModem.SimSecurityStatusChangedEvent, self).listElements()
            return elements

    # value object
    class SimPinUpdatedEvent(raritan.rpc.idl.Event):
        idlType = "serial.GsmModem_1_0_2.SimPinUpdatedEvent:1.0.0"

        def __init__(self, newPin, source):
            super(raritan.rpc.serial.GsmModem.SimPinUpdatedEvent, self).__init__(source)
            typecheck.is_string(newPin, AssertionError)

            self.newPin = newPin

        def encode(self):
            json = super(raritan.rpc.serial.GsmModem.SimPinUpdatedEvent, self).encode()
            json['newPin'] = self.newPin
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                newPin = json['newPin'],
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["newPin"]
            elements = elements + super(raritan.rpc.serial.GsmModem.SimPinUpdatedEvent, self).listElements()
            return elements

    class _getSettings(Interface.Method):
        name = 'getSettings'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = raritan.rpc.serial.GsmModem.Settings.decode(rsp['_ret_'], agent)
            typecheck.is_struct(_ret_, raritan.rpc.serial.GsmModem.Settings, DecodeException)
            return _ret_

    class _setSettings(Interface.Method):
        name = 'setSettings'

        @staticmethod
        def encode(settings):
            typecheck.is_struct(settings, raritan.rpc.serial.GsmModem.Settings, AssertionError)
            args = {}
            args['settings'] = raritan.rpc.serial.GsmModem.Settings.encode(settings)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _sendSms(Interface.Method):
        name = 'sendSms'

        @staticmethod
        def encode(recipient, text):
            typecheck.is_string(recipient, AssertionError)
            typecheck.is_string(text, AssertionError)
            args = {}
            args['recipient'] = recipient
            args['text'] = text
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _sendTestSms(Interface.Method):
        name = 'sendTestSms'

        @staticmethod
        def encode(recipient, testSettings):
            typecheck.is_string(recipient, AssertionError)
            typecheck.is_struct(testSettings, raritan.rpc.serial.GsmModem.Settings, AssertionError)
            args = {}
            args['recipient'] = recipient
            args['testSettings'] = raritan.rpc.serial.GsmModem.Settings.encode(testSettings)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _getInformation(Interface.Method):
        name = 'getInformation'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            info = raritan.rpc.serial.GsmModem.Information.decode(rsp['info'], agent)
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_struct(info, raritan.rpc.serial.GsmModem.Information, DecodeException)
            return (_ret_, info)

    class _getInformationWithPin(Interface.Method):
        name = 'getInformationWithPin'

        @staticmethod
        def encode(pin):
            typecheck.is_string(pin, AssertionError)
            args = {}
            args['pin'] = pin
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            info = raritan.rpc.serial.GsmModem.Information.decode(rsp['info'], agent)
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_struct(info, raritan.rpc.serial.GsmModem.Information, DecodeException)
            return (_ret_, info)

    class _getSimSecurityStatus(Interface.Method):
        name = 'getSimSecurityStatus'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            simStatus = raritan.rpc.serial.GsmModem.SimSecurityStatus.decode(rsp['simStatus'])
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_enum(simStatus, raritan.rpc.serial.GsmModem.SimSecurityStatus, DecodeException)
            return (_ret_, simStatus)

    class _unlockSimCard(Interface.Method):
        name = 'unlockSimCard'

        @staticmethod
        def encode(puk, newPin):
            typecheck.is_string(puk, AssertionError)
            typecheck.is_string(newPin, AssertionError)
            args = {}
            args['puk'] = puk
            args['newPin'] = newPin
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_
    def __init__(self, target, agent):
        super(GsmModem, self).__init__(target, agent)
        self.getSettings = GsmModem._getSettings(self)
        self.setSettings = GsmModem._setSettings(self)
        self.sendSms = GsmModem._sendSms(self)
        self.sendTestSms = GsmModem._sendTestSms(self)
        self.getInformation = GsmModem._getInformation(self)
        self.getInformationWithPin = GsmModem._getInformationWithPin(self)
        self.getSimSecurityStatus = GsmModem._getSimSecurityStatus(self)
        self.unlockSimCard = GsmModem._unlockSimCard(self)

#
# Section generated by IdlC from "SerialPort.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.idl

import raritan.rpc.serial


# interface
class SerialPort(Interface):
    idlType = "serial.SerialPort:3.0.1"

    SUCCESS = 0

    ERR_INVALID_VALUE = 1

    # enumeration
    class PortState(Enumeration):
        idlType = "serial.SerialPort_3_0_1.PortState:1.0.0"
        values = ["CONSOLE", "ANALOGMODEM", "GSMMODEM", "DISCONNECTED"]

    PortState.CONSOLE = PortState(0)
    PortState.ANALOGMODEM = PortState(1)
    PortState.GSMMODEM = PortState(2)
    PortState.DISCONNECTED = PortState(3)

    # enumeration
    class DetectionType(Enumeration):
        idlType = "serial.SerialPort_3_0_1.DetectionType:1.0.0"
        values = ["AUTOMATIC", "FORCE_CONSOLE", "FORCE_ANALOGMODEM", "FORCE_GSMMODEM"]

    DetectionType.AUTOMATIC = DetectionType(0)
    DetectionType.FORCE_CONSOLE = DetectionType(1)
    DetectionType.FORCE_ANALOGMODEM = DetectionType(2)
    DetectionType.FORCE_GSMMODEM = DetectionType(3)

    # enumeration
    class BaudRate(Enumeration):
        idlType = "serial.SerialPort_3_0_1.BaudRate:1.0.0"
        values = ["BR1200", "BR2400", "BR4800", "BR9600", "BR19200", "BR38400", "BR57600", "BR115200"]

    BaudRate.BR1200 = BaudRate(0)
    BaudRate.BR2400 = BaudRate(1)
    BaudRate.BR4800 = BaudRate(2)
    BaudRate.BR9600 = BaudRate(3)
    BaudRate.BR19200 = BaudRate(4)
    BaudRate.BR38400 = BaudRate(5)
    BaudRate.BR57600 = BaudRate(6)
    BaudRate.BR115200 = BaudRate(7)

    # structure
    class MetaData(Structure):
        idlType = "serial.SerialPort_3_0_1.MetaData:1.0.0"
        elements = ["hasModemSupport"]

        def __init__(self, hasModemSupport):
            typecheck.is_bool(hasModemSupport, AssertionError)

            self.hasModemSupport = hasModemSupport

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                hasModemSupport = json['hasModemSupport'],
            )
            return obj

        def encode(self):
            json = {}
            json['hasModemSupport'] = self.hasModemSupport
            return json

    # structure
    class State(Structure):
        idlType = "serial.SerialPort_3_0_1.State:1.0.0"
        elements = ["state", "deviceName"]

        def __init__(self, state, deviceName):
            typecheck.is_enum(state, raritan.rpc.serial.SerialPort.PortState, AssertionError)
            typecheck.is_string(deviceName, AssertionError)

            self.state = state
            self.deviceName = deviceName

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                state = raritan.rpc.serial.SerialPort.PortState.decode(json['state']),
                deviceName = json['deviceName'],
            )
            return obj

        def encode(self):
            json = {}
            json['state'] = raritan.rpc.serial.SerialPort.PortState.encode(self.state)
            json['deviceName'] = self.deviceName
            return json

    # structure
    class Settings(Structure):
        idlType = "serial.SerialPort_3_0_1.Settings:1.0.0"
        elements = ["consoleBaudRate", "modemBaudRate", "detectType"]

        def __init__(self, consoleBaudRate, modemBaudRate, detectType):
            typecheck.is_enum(consoleBaudRate, raritan.rpc.serial.SerialPort.BaudRate, AssertionError)
            typecheck.is_enum(modemBaudRate, raritan.rpc.serial.SerialPort.BaudRate, AssertionError)
            typecheck.is_enum(detectType, raritan.rpc.serial.SerialPort.DetectionType, AssertionError)

            self.consoleBaudRate = consoleBaudRate
            self.modemBaudRate = modemBaudRate
            self.detectType = detectType

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                consoleBaudRate = raritan.rpc.serial.SerialPort.BaudRate.decode(json['consoleBaudRate']),
                modemBaudRate = raritan.rpc.serial.SerialPort.BaudRate.decode(json['modemBaudRate']),
                detectType = raritan.rpc.serial.SerialPort.DetectionType.decode(json['detectType']),
            )
            return obj

        def encode(self):
            json = {}
            json['consoleBaudRate'] = raritan.rpc.serial.SerialPort.BaudRate.encode(self.consoleBaudRate)
            json['modemBaudRate'] = raritan.rpc.serial.SerialPort.BaudRate.encode(self.modemBaudRate)
            json['detectType'] = raritan.rpc.serial.SerialPort.DetectionType.encode(self.detectType)
            return json

    # value object
    class ModemEvent(raritan.rpc.idl.Event):
        idlType = "serial.SerialPort_3_0_1.ModemEvent:1.0.0"

        def __init__(self, modem, source):
            super(raritan.rpc.serial.SerialPort.ModemEvent, self).__init__(source)
            typecheck.is_remote_obj(modem, AssertionError)

            self.modem = modem

        def encode(self):
            json = super(raritan.rpc.serial.SerialPort.ModemEvent, self).encode()
            json['modem'] = Interface.encode(self.modem)
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                modem = Interface.decode(json['modem'], agent),
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["modem"]
            elements = elements + super(raritan.rpc.serial.SerialPort.ModemEvent, self).listElements()
            return elements

    # value object
    class ModemAddedEvent(ModemEvent):
        idlType = "serial.SerialPort_3_0_1.ModemAddedEvent:1.0.0"

        def __init__(self, modem, source):
            super(raritan.rpc.serial.SerialPort.ModemAddedEvent, self).__init__(modem, source)

        def encode(self):
            json = super(raritan.rpc.serial.SerialPort.ModemAddedEvent, self).encode()
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                # for serial.SerialPort_3_0_1.ModemEvent
                modem = Interface.decode(json['modem'], agent),
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = []
            elements = elements + super(raritan.rpc.serial.SerialPort.ModemAddedEvent, self).listElements()
            return elements

    # value object
    class ModemRemovedEvent(ModemEvent):
        idlType = "serial.SerialPort_3_0_1.ModemRemovedEvent:1.0.0"

        def __init__(self, modem, source):
            super(raritan.rpc.serial.SerialPort.ModemRemovedEvent, self).__init__(modem, source)

        def encode(self):
            json = super(raritan.rpc.serial.SerialPort.ModemRemovedEvent, self).encode()
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                # for serial.SerialPort_3_0_1.ModemEvent
                modem = Interface.decode(json['modem'], agent),
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = []
            elements = elements + super(raritan.rpc.serial.SerialPort.ModemRemovedEvent, self).listElements()
            return elements

    class _getMetaData(Interface.Method):
        name = 'getMetaData'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = raritan.rpc.serial.SerialPort.MetaData.decode(rsp['_ret_'], agent)
            typecheck.is_struct(_ret_, raritan.rpc.serial.SerialPort.MetaData, DecodeException)
            return _ret_

    class _getSettings(Interface.Method):
        name = 'getSettings'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = raritan.rpc.serial.SerialPort.Settings.decode(rsp['_ret_'], agent)
            typecheck.is_struct(_ret_, raritan.rpc.serial.SerialPort.Settings, DecodeException)
            return _ret_

    class _setSettings(Interface.Method):
        name = 'setSettings'

        @staticmethod
        def encode(settings):
            typecheck.is_struct(settings, raritan.rpc.serial.SerialPort.Settings, AssertionError)
            args = {}
            args['settings'] = raritan.rpc.serial.SerialPort.Settings.encode(settings)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _getState(Interface.Method):
        name = 'getState'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = raritan.rpc.serial.SerialPort.State.decode(rsp['_ret_'], agent)
            typecheck.is_struct(_ret_, raritan.rpc.serial.SerialPort.State, DecodeException)
            return _ret_

    class _getModem(Interface.Method):
        name = 'getModem'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = Interface.decode(rsp['_ret_'], agent)
            typecheck.is_remote_obj(_ret_, DecodeException)
            return _ret_
    def __init__(self, target, agent):
        super(SerialPort, self).__init__(target, agent)
        self.getMetaData = SerialPort._getMetaData(self)
        self.getSettings = SerialPort._getSettings(self)
        self.setSettings = SerialPort._setSettings(self)
        self.getState = SerialPort._getState(self)
        self.getModem = SerialPort._getModem(self)

#
# Section generated by IdlC from "PortDispatcher.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException

# interface
class PortDispatcher(Interface):
    idlType = "serial.PortDispatcher:1.2.2"

    class _getPorts(Interface.Method):
        name = 'getPorts'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = dict([(
                elem['key'],
                Interface.decode(elem['value'], agent))
                for elem in rsp['_ret_']])
            return _ret_
    def __init__(self, target, agent):
        super(PortDispatcher, self).__init__(target, agent)
        self.getPorts = PortDispatcher._getPorts(self)



# SPDX-License-Identifier: BSD-3-Clause
#
# Copyright 2020 Raritan Inc. All rights reserved.
#
# This is an auto-generated file.

#
# Section generated by IdlC from "ExternalBeeper.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.hmi

import raritan.rpc.idl


# interface
class ExternalBeeper(Interface):
    idlType = "hmi.ExternalBeeper:1.0.1"

    # enumeration
    class State(Enumeration):
        idlType = "hmi.ExternalBeeper_1_0_1.State:1.0.0"
        values = ["OFF", "ON", "ALARMING"]

    State.OFF = State(0)
    State.ON = State(1)
    State.ALARMING = State(2)

    # value object
    class StateChangedEvent(raritan.rpc.idl.Event):
        idlType = "hmi.ExternalBeeper_1_0_1.StateChangedEvent:1.0.0"

        def __init__(self, oldState, newState, source):
            super(raritan.rpc.hmi.ExternalBeeper.StateChangedEvent, self).__init__(source)
            typecheck.is_enum(oldState, raritan.rpc.hmi.ExternalBeeper.State, AssertionError)
            typecheck.is_enum(newState, raritan.rpc.hmi.ExternalBeeper.State, AssertionError)

            self.oldState = oldState
            self.newState = newState

        def encode(self):
            json = super(raritan.rpc.hmi.ExternalBeeper.StateChangedEvent, self).encode()
            json['oldState'] = raritan.rpc.hmi.ExternalBeeper.State.encode(self.oldState)
            json['newState'] = raritan.rpc.hmi.ExternalBeeper.State.encode(self.newState)
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                oldState = raritan.rpc.hmi.ExternalBeeper.State.decode(json['oldState']),
                newState = raritan.rpc.hmi.ExternalBeeper.State.decode(json['newState']),
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["oldState", "newState"]
            elements = elements + super(raritan.rpc.hmi.ExternalBeeper.StateChangedEvent, self).listElements()
            return elements

    class _getState(Interface.Method):
        name = 'getState'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = raritan.rpc.hmi.ExternalBeeper.State.decode(rsp['_ret_'])
            typecheck.is_enum(_ret_, raritan.rpc.hmi.ExternalBeeper.State, DecodeException)
            return _ret_

    class _alarm(Interface.Method):
        name = 'alarm'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _on(Interface.Method):
        name = 'on'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _off(Interface.Method):
        name = 'off'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            return None
    def __init__(self, target, agent):
        super(ExternalBeeper, self).__init__(target, agent)
        self.getState = ExternalBeeper._getState(self)
        self.alarm = ExternalBeeper._alarm(self)
        self.on = ExternalBeeper._on(self)
        self.off = ExternalBeeper._off(self)

#
# Section generated by IdlC from "InternalBeeper.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.event

import raritan.rpc.hmi

import raritan.rpc.idl


# interface
class InternalBeeper(Interface):
    idlType = "hmi.InternalBeeper:2.0.1"

    # enumeration
    class State(Enumeration):
        idlType = "hmi.InternalBeeper_2_0_1.State:1.0.0"
        values = ["OFF", "ON_NOTIFICATION", "ON_ACTIVATION"]

    State.OFF = State(0)
    State.ON_NOTIFICATION = State(1)
    State.ON_ACTIVATION = State(2)

    # value object
    class MuteChangedEvent(raritan.rpc.event.UserEvent):
        idlType = "hmi.InternalBeeper_2_0_1.MuteChangedEvent:1.0.0"

        def __init__(self, muted, actUserName, actIpAddr, source):
            super(raritan.rpc.hmi.InternalBeeper.MuteChangedEvent, self).__init__(actUserName, actIpAddr, source)
            typecheck.is_bool(muted, AssertionError)

            self.muted = muted

        def encode(self):
            json = super(raritan.rpc.hmi.InternalBeeper.MuteChangedEvent, self).encode()
            json['muted'] = self.muted
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                muted = json['muted'],
                # for event.UserEvent
                actUserName = json['actUserName'],
                actIpAddr = json['actIpAddr'],
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["muted"]
            elements = elements + super(raritan.rpc.hmi.InternalBeeper.MuteChangedEvent, self).listElements()
            return elements

    # value object
    class StateChangedEvent(raritan.rpc.idl.Event):
        idlType = "hmi.InternalBeeper_2_0_1.StateChangedEvent:1.0.0"

        def __init__(self, state, reason, mutedTemporarily, source):
            super(raritan.rpc.hmi.InternalBeeper.StateChangedEvent, self).__init__(source)
            typecheck.is_enum(state, raritan.rpc.hmi.InternalBeeper.State, AssertionError)
            typecheck.is_string(reason, AssertionError)
            typecheck.is_bool(mutedTemporarily, AssertionError)

            self.state = state
            self.reason = reason
            self.mutedTemporarily = mutedTemporarily

        def encode(self):
            json = super(raritan.rpc.hmi.InternalBeeper.StateChangedEvent, self).encode()
            json['state'] = raritan.rpc.hmi.InternalBeeper.State.encode(self.state)
            json['reason'] = self.reason
            json['mutedTemporarily'] = self.mutedTemporarily
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                state = raritan.rpc.hmi.InternalBeeper.State.decode(json['state']),
                reason = json['reason'],
                mutedTemporarily = json['mutedTemporarily'],
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["state", "reason", "mutedTemporarily"]
            elements = elements + super(raritan.rpc.hmi.InternalBeeper.StateChangedEvent, self).listElements()
            return elements

    class _mute(Interface.Method):
        name = 'mute'

        @staticmethod
        def encode(muted):
            typecheck.is_bool(muted, AssertionError)
            args = {}
            args['muted'] = muted
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _isMuted(Interface.Method):
        name = 'isMuted'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_bool(_ret_, DecodeException)
            return _ret_

    class _activate(Interface.Method):
        name = 'activate'

        @staticmethod
        def encode(on, reason, timeout):
            typecheck.is_bool(on, AssertionError)
            typecheck.is_string(reason, AssertionError)
            typecheck.is_int(timeout, AssertionError)
            args = {}
            args['on'] = on
            args['reason'] = reason
            args['timeout'] = timeout
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _getState(Interface.Method):
        name = 'getState'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = raritan.rpc.hmi.InternalBeeper.State.decode(rsp['_ret_'])
            reason = rsp['reason']
            mutedTemporarily = rsp['mutedTemporarily']
            typecheck.is_enum(_ret_, raritan.rpc.hmi.InternalBeeper.State, DecodeException)
            typecheck.is_string(reason, DecodeException)
            typecheck.is_bool(mutedTemporarily, DecodeException)
            return (_ret_, reason, mutedTemporarily)

    class _muteCurrentActivation(Interface.Method):
        name = 'muteCurrentActivation'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            return None
    def __init__(self, target, agent):
        super(InternalBeeper, self).__init__(target, agent)
        self.mute = InternalBeeper._mute(self)
        self.isMuted = InternalBeeper._isMuted(self)
        self.activate = InternalBeeper._activate(self)
        self.getState = InternalBeeper._getState(self)
        self.muteCurrentActivation = InternalBeeper._muteCurrentActivation(self)



# SPDX-License-Identifier: BSD-3-Clause
#
# Copyright 2010 Raritan Inc. All rights reserved.

import raritan.rpc

class Structure(object):
    def __str__(self):
        l = max([len(e) for e in self.elements])
        pretty = "\n".join([
            raritan.rpc.Utils.indent("* %-*s = %s" % (l, e, raritan.rpc.Utils.rprint(getattr(self, e))), 4) for e in self.elements
        ])
        return "%s:\n%s" % (raritan.rpc.TypeInfo.typeBaseName(self.idlType), pretty)

    def __eq__(self, other):
        return (other != None and self.idlType == other.idlType and
                all([getattr(self, e) == getattr(other, e) for e in self.elements]))

    def __hash__(self):
        return hash((self.idlType, tuple(self.elements)))



# SPDX-License-Identifier: BSD-3-Clause
#
# Copyright 2013 Raritan Inc. All rights reserved.

import raritan.rpc

class ValueObject(object):
    def __init__(self):
        pass

    @staticmethod
    def decode(json, agent):
        if not json:
            return None
        class_ = raritan.rpc.TypeInfo.decode(json['type'])
        obj = class_.decode(json['value'], agent)
        return obj

    @staticmethod
    def encode(obj):
      json = {}
      json['type'] = obj.idlType
      json['value'] = obj.encode()
      return json

    def listValues(self):
        return [getattr(self, e) for e in self.listElements()]

    def __str__(self):
        elements = self.listElements()
        l = max([len(e) for e in elements])
        pretty = "\n".join([
            raritan.rpc.Utils.indent("* %-*s = %s" % (l, e, raritan.rpc.Utils.rprint(getattr(self, e))), 4) for e in elements
        ])
        return "%s:\n%s" % (raritan.rpc.TypeInfo.typeBaseName(self.idlType), pretty)

    def __eq__(self, other):
        return (other != None and self.idlType == other.idlType and self.listValues() == other.listValues())

    def __hash__(self):
        return hash((self.idlType, tuple(self.listValues())))



# SPDX-License-Identifier: BSD-3-Clause
#
# Copyright 2013 Raritan Inc. All rights reserved.

# Avoid name clash with raritan.rpc.sys
from __future__ import absolute_import
import sys

class Utils(object):

    @staticmethod
    def indent(string, indent):
        return "\n".join([(" " * indent) + l for l in string.splitlines()])

    @staticmethod
    def rprint(object):
        if sys.version_info.major < 3:
            if isinstance(object, basestring):
                return '"' + str(object) + '"'
        else:
            if isinstance(object, str):
                return '"' + str(object) + '"'

        if isinstance(object, list):
            if len(object) == 0:
                return '[]'
            else:
                return '[\n' + ',\n'.join(Utils.indent(Utils.rprint(x), 4) for x in object) + '\n]'
        elif isinstance(object, dict):
            if len(object) == 0:
                return '{}'
            else:
                return '{\n' + "\n".join(Utils.indent("%s = %s" % (x, Utils.rprint(object[x])), 4) for x in sorted(object)) + '\n}'
        return str(object)



# SPDX-License-Identifier: BSD-3-Clause
#
# Copyright 2020 Raritan Inc. All rights reserved.
#
# This is an auto-generated file.

#
# Section generated by IdlC from "Production.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException

# interface
class Production(Interface):
    idlType = "production.Production:1.0.0"

    class _enterFactoryConfigMode(Interface.Method):
        name = 'enterFactoryConfigMode'

        @staticmethod
        def encode(password):
            typecheck.is_string(password, AssertionError)
            args = {}
            args['password'] = password
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _leaveFactoryConfigMode(Interface.Method):
        name = 'leaveFactoryConfigMode'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _isFactoryConfigModeEnabled(Interface.Method):
        name = 'isFactoryConfigModeEnabled'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_bool(_ret_, DecodeException)
            return _ret_
    def __init__(self, target, agent):
        super(Production, self).__init__(target, agent)
        self.enterFactoryConfigMode = Production._enterFactoryConfigMode(self)
        self.leaveFactoryConfigMode = Production._leaveFactoryConfigMode(self)
        self.isFactoryConfigModeEnabled = Production._isFactoryConfigModeEnabled(self)



# SPDX-License-Identifier: BSD-3-Clause
#
# Copyright 2020 Raritan Inc. All rights reserved.
#
# This is an auto-generated file.

#
# Section generated by IdlC from "TestDisplay.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.test


# interface
class Display(Interface):
    idlType = "test.Display:1.0.1"

    # enumeration
    class Orientation(Enumeration):
        idlType = "test.Display_1_0_1.Orientation:1.0.0"
        values = ["NORMAL", "FLIPPED", "LEFT", "RIGHT"]

    Orientation.NORMAL = Orientation(0)
    Orientation.FLIPPED = Orientation(1)
    Orientation.LEFT = Orientation(2)
    Orientation.RIGHT = Orientation(3)

    # structure
    class Info(Structure):
        idlType = "test.Display_1_0_1.Info:1.0.0"
        elements = ["type", "address", "options", "orientation"]

        def __init__(self, type, address, options, orientation):
            typecheck.is_string(type, AssertionError)
            typecheck.is_string(address, AssertionError)
            typecheck.is_enum(orientation, raritan.rpc.test.Display.Orientation, AssertionError)

            self.type = type
            self.address = address
            self.options = options
            self.orientation = orientation

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                type = json['type'],
                address = json['address'],
                options = dict([(
                    elem['key'],
                    elem['value'])
                    for elem in json['options']]),
                orientation = raritan.rpc.test.Display.Orientation.decode(json['orientation']),
            )
            return obj

        def encode(self):
            json = {}
            json['type'] = self.type
            json['address'] = self.address
            json['options'] = [dict(
                key = k,
                value = v)
                for k, v in self.options.items()]
            json['orientation'] = raritan.rpc.test.Display.Orientation.encode(self.orientation)
            return json

    class _getInfo(Interface.Method):
        name = 'getInfo'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = raritan.rpc.test.Display.Info.decode(rsp['_ret_'], agent)
            typecheck.is_struct(_ret_, raritan.rpc.test.Display.Info, DecodeException)
            return _ret_

    class _testSequence(Interface.Method):
        name = 'testSequence'

        @staticmethod
        def encode(cycleTime_ms):
            typecheck.is_int(cycleTime_ms, AssertionError)
            args = {}
            args['cycleTime_ms'] = cycleTime_ms
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    # enumeration
    class TestStatus(Enumeration):
        idlType = "test.Display_1_0_1.TestStatus:1.0.0"
        values = ["TEST_IDLE", "TEST_BUSY", "TEST_PASSED", "TEST_FAILED"]

    TestStatus.TEST_IDLE = TestStatus(0)
    TestStatus.TEST_BUSY = TestStatus(1)
    TestStatus.TEST_PASSED = TestStatus(2)
    TestStatus.TEST_FAILED = TestStatus(3)

    class _enterTestMode(Interface.Method):
        name = 'enterTestMode'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _getTestStatus(Interface.Method):
        name = 'getTestStatus'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = raritan.rpc.test.Display.TestStatus.decode(rsp['_ret_'])
            typecheck.is_enum(_ret_, raritan.rpc.test.Display.TestStatus, DecodeException)
            return _ret_
    def __init__(self, target, agent):
        super(Display, self).__init__(target, agent)
        self.getInfo = Display._getInfo(self)
        self.testSequence = Display._testSequence(self)
        self.enterTestMode = Display._enterTestMode(self)
        self.getTestStatus = Display._getTestStatus(self)

#
# Section generated by IdlC from "TestUnit.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.test


# interface
class Unit(Interface):
    idlType = "test.Unit:1.0.2"

    class _getDisplays(Interface.Method):
        name = 'getDisplays'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = [Interface.decode(x0, agent) for x0 in rsp['_ret_']]
            for x0 in _ret_:
                typecheck.is_interface(x0, raritan.rpc.test.Display, DecodeException)
            return _ret_

    class _getButtonStates(Interface.Method):
        name = 'getButtonStates'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = [x0 for x0 in rsp['_ret_']]
            for x0 in _ret_:
                typecheck.is_bool(x0, DecodeException)
            return _ret_

    class _setBuzzer(Interface.Method):
        name = 'setBuzzer'

        @staticmethod
        def encode(isOn):
            typecheck.is_bool(isOn, AssertionError)
            args = {}
            args['isOn'] = isOn
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _resetAllSlaveControllers(Interface.Method):
        name = 'resetAllSlaveControllers'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _triggerSlaveControllerWatchdog(Interface.Method):
        name = 'triggerSlaveControllerWatchdog'

        @staticmethod
        def encode(rs485Addr):
            typecheck.is_int(rs485Addr, AssertionError)
            args = {}
            args['rs485Addr'] = rs485Addr
            return args

        @staticmethod
        def decode(rsp, agent):
            return None
    def __init__(self, target, agent):
        super(Unit, self).__init__(target, agent)
        self.getDisplays = Unit._getDisplays(self)
        self.getButtonStates = Unit._getButtonStates(self)
        self.setBuzzer = Unit._setBuzzer(self)
        self.resetAllSlaveControllers = Unit._resetAllSlaveControllers(self)
        self.triggerSlaveControllerWatchdog = Unit._triggerSlaveControllerWatchdog(self)

#
# Section generated by IdlC from "testrpc.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.test


# structure
class Result(Structure):
    idlType = "test.Result:1.0.0"
    elements = ["code", "errtext"]

    def __init__(self, code, errtext):
        typecheck.is_int(code, AssertionError)
        typecheck.is_string(errtext, AssertionError)

        self.code = code
        self.errtext = errtext

    @classmethod
    def decode(cls, json, agent):
        obj = cls(
            code = json['code'],
            errtext = json['errtext'],
        )
        return obj

    def encode(self):
        json = {}
        json['code'] = self.code
        json['errtext'] = self.errtext
        return json

# interface
class Control(Interface):
    idlType = "test.Control:1.0.0"

    class _isTestMode(Interface.Method):
        name = 'isTestMode'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_bool(_ret_, DecodeException)
            return _ret_

    class _setTestMode(Interface.Method):
        name = 'setTestMode'

        @staticmethod
        def encode(isTestModeOn):
            typecheck.is_bool(isTestModeOn, AssertionError)
            args = {}
            args['isTestModeOn'] = isTestModeOn
            return args

        @staticmethod
        def decode(rsp, agent):
            return None
    def __init__(self, target, agent):
        super(Control, self).__init__(target, agent)
        self.isTestMode = Control._isTestMode(self)
        self.setTestMode = Control._setTestMode(self)

# interface
class RS232Serial(Interface):
    idlType = "test.RS232Serial:1.0.0"

    class _getDeviceFiles(Interface.Method):
        name = 'getDeviceFiles'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = [x0 for x0 in rsp['_ret_']]
            for x0 in _ret_:
                typecheck.is_string(x0, DecodeException)
            return _ret_

    class _testLoop1(Interface.Method):
        name = 'testLoop1'

        @staticmethod
        def encode(devfile):
            typecheck.is_string(devfile, AssertionError)
            args = {}
            args['devfile'] = devfile
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = raritan.rpc.test.Result.decode(rsp['_ret_'], agent)
            typecheck.is_struct(_ret_, raritan.rpc.test.Result, DecodeException)
            return _ret_

    class _testLoop2(Interface.Method):
        name = 'testLoop2'

        @staticmethod
        def encode(devfile):
            typecheck.is_string(devfile, AssertionError)
            args = {}
            args['devfile'] = devfile
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = raritan.rpc.test.Result.decode(rsp['_ret_'], agent)
            typecheck.is_struct(_ret_, raritan.rpc.test.Result, DecodeException)
            return _ret_
    def __init__(self, target, agent):
        super(RS232Serial, self).__init__(target, agent)
        self.getDeviceFiles = RS232Serial._getDeviceFiles(self)
        self.testLoop1 = RS232Serial._testLoop1(self)
        self.testLoop2 = RS232Serial._testLoop2(self)

# interface
class FeatSerial(Interface):
    idlType = "test.FeatSerial:1.0.0"

    OK = 0

    ERR_NO_TEST_MODE = 1

    ERR_INVAL_PORT_NUM = 2

    ERR_TEST_FAILED = 3

    class _getNumberOfPorts(Interface.Method):
        name = 'getNumberOfPorts'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            numPorts = rsp['numPorts']
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_int(numPorts, DecodeException)
            return (_ret_, numPorts)

    class _setPower(Interface.Method):
        name = 'setPower'

        @staticmethod
        def encode(portNum, hasPower):
            typecheck.is_int(portNum, AssertionError)
            typecheck.is_bool(hasPower, AssertionError)
            args = {}
            args['portNum'] = portNum
            args['hasPower'] = hasPower
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _testLoopTxRx(Interface.Method):
        name = 'testLoopTxRx'

        @staticmethod
        def encode(portNum):
            typecheck.is_int(portNum, AssertionError)
            args = {}
            args['portNum'] = portNum
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            errstr = rsp['errstr']
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_string(errstr, DecodeException)
            return (_ret_, errstr)

    class _testLoopDtrDcd(Interface.Method):
        name = 'testLoopDtrDcd'

        @staticmethod
        def encode(portNum):
            typecheck.is_int(portNum, AssertionError)
            args = {}
            args['portNum'] = portNum
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            errstr = rsp['errstr']
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_string(errstr, DecodeException)
            return (_ret_, errstr)
    def __init__(self, target, agent):
        super(FeatSerial, self).__init__(target, agent)
        self.getNumberOfPorts = FeatSerial._getNumberOfPorts(self)
        self.setPower = FeatSerial._setPower(self)
        self.testLoopTxRx = FeatSerial._testLoopTxRx(self)
        self.testLoopDtrDcd = FeatSerial._testLoopDtrDcd(self)

# interface
class AuxSerial(Interface):
    idlType = "test.AuxSerial:1.0.0"

    OK = 0

    ERR_NO_TEST_MODE = 1

    ERR_INVAL_PORT_NUM = 2

    ERR_TEST_FAILED = 3

    class _getNumberOfPorts(Interface.Method):
        name = 'getNumberOfPorts'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            numPorts = rsp['numPorts']
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_int(numPorts, DecodeException)
            return (_ret_, numPorts)

    class _testLoop(Interface.Method):
        name = 'testLoop'

        @staticmethod
        def encode(portNum):
            typecheck.is_int(portNum, AssertionError)
            args = {}
            args['portNum'] = portNum
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            errstr = rsp['errstr']
            typecheck.is_int(_ret_, DecodeException)
            typecheck.is_string(errstr, DecodeException)
            return (_ret_, errstr)
    def __init__(self, target, agent):
        super(AuxSerial, self).__init__(target, agent)
        self.getNumberOfPorts = AuxSerial._getNumberOfPorts(self)
        self.testLoop = AuxSerial._testLoop(self)

# interface
class Ethernet(Interface):
    idlType = "test.Ethernet:1.0.0"

    class _getDevices(Interface.Method):
        name = 'getDevices'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = [x0 for x0 in rsp['_ret_']]
            for x0 in _ret_:
                typecheck.is_string(x0, DecodeException)
            return _ret_

    # enumeration
    class Speed(Enumeration):
        idlType = "test.Ethernet.Speed:1.0.0"
        values = ["SPD_10", "SPD_100", "SPD_1000"]

    Speed.SPD_10 = Speed(0)
    Speed.SPD_100 = Speed(1)
    Speed.SPD_1000 = Speed(2)

    # enumeration
    class Duplex(Enumeration):
        idlType = "test.Ethernet.Duplex:1.0.0"
        values = ["DPX_HALF", "DPX_FULL"]

    Duplex.DPX_HALF = Duplex(0)
    Duplex.DPX_FULL = Duplex(1)

    class _setParameters(Interface.Method):
        name = 'setParameters'

        @staticmethod
        def encode(device, speed, duplex, isAutoNeg):
            typecheck.is_string(device, AssertionError)
            typecheck.is_enum(speed, raritan.rpc.test.Ethernet.Speed, AssertionError)
            typecheck.is_enum(duplex, raritan.rpc.test.Ethernet.Duplex, AssertionError)
            typecheck.is_bool(isAutoNeg, AssertionError)
            args = {}
            args['device'] = device
            args['speed'] = raritan.rpc.test.Ethernet.Speed.encode(speed)
            args['duplex'] = raritan.rpc.test.Ethernet.Duplex.encode(duplex)
            args['isAutoNeg'] = isAutoNeg
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_
    def __init__(self, target, agent):
        super(Ethernet, self).__init__(target, agent)
        self.getDevices = Ethernet._getDevices(self)
        self.setParameters = Ethernet._setParameters(self)



# SPDX-License-Identifier: BSD-3-Clause
#
# Copyright 2020 Raritan Inc. All rights reserved.
#
# This is an auto-generated file.

#
# Section generated by IdlC from "CascadeManager.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.cascading

import raritan.rpc.event

import raritan.rpc.idl


# interface
class CascadeManager(Interface):
    idlType = "cascading.CascadeManager:1.0.0"

    NO_ERROR = 0

    ERR_INVALID_PARAM = 1

    ERR_UNSUPPORTED_ON_MASTER = 2

    ERR_UNSUPPORTED_ON_LINK_UNIT = 3

    ERR_LINK_ID_IN_USE = 4

    ERR_HOST_IN_USE = 5

    ERR_LINK_UNIT_UNREACHABLE = 6

    ERR_LINK_UNIT_ACCESS_DENIED = 7

    ERR_LINK_UNIT_REFUSED = 8

    ERR_UNIT_BUSY = 9

    ERR_NOT_SUPPORTED = 10

    ERR_PASSWORD_CHANGE_REQUIRED = 11

    ERR_PASSWORD_POLICY = 12

    # enumeration
    class Role(Enumeration):
        idlType = "cascading.CascadeManager.Role:1.0.0"
        values = ["STANDALONE", "MASTER", "LINK_UNIT"]

    Role.STANDALONE = Role(0)
    Role.MASTER = Role(1)
    Role.LINK_UNIT = Role(2)

    # enumeration
    class LinkUnitStatus(Enumeration):
        idlType = "cascading.CascadeManager.LinkUnitStatus:1.0.0"
        values = ["UNKNOWN", "OK", "UNREACHABLE", "ACCESS_DENIED", "FIRMWARE_UPDATE"]

    LinkUnitStatus.UNKNOWN = LinkUnitStatus(0)
    LinkUnitStatus.OK = LinkUnitStatus(1)
    LinkUnitStatus.UNREACHABLE = LinkUnitStatus(2)
    LinkUnitStatus.ACCESS_DENIED = LinkUnitStatus(3)
    LinkUnitStatus.FIRMWARE_UPDATE = LinkUnitStatus(4)
    LinkUnitStatus._fallback = LinkUnitStatus.UNKNOWN

    # structure
    class LinkUnit(Structure):
        idlType = "cascading.CascadeManager.LinkUnit:1.0.0"
        elements = ["host", "status"]

        def __init__(self, host, status):
            typecheck.is_string(host, AssertionError)
            typecheck.is_enum(status, raritan.rpc.cascading.CascadeManager.LinkUnitStatus, AssertionError)

            self.host = host
            self.status = status

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                host = json['host'],
                status = raritan.rpc.cascading.CascadeManager.LinkUnitStatus.decode(json['status']),
            )
            return obj

        def encode(self):
            json = {}
            json['host'] = self.host
            json['status'] = raritan.rpc.cascading.CascadeManager.LinkUnitStatus.encode(self.status)
            return json

    # structure
    class Status(Structure):
        idlType = "cascading.CascadeManager.Status:1.0.0"
        elements = ["role", "master", "linkUnits"]

        def __init__(self, role, master, linkUnits):
            typecheck.is_enum(role, raritan.rpc.cascading.CascadeManager.Role, AssertionError)
            typecheck.is_string(master, AssertionError)

            self.role = role
            self.master = master
            self.linkUnits = linkUnits

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                role = raritan.rpc.cascading.CascadeManager.Role.decode(json['role']),
                master = json['master'],
                linkUnits = dict([(
                    elem['key'],
                    raritan.rpc.cascading.CascadeManager.LinkUnit.decode(elem['value'], agent))
                    for elem in json['linkUnits']]),
            )
            return obj

        def encode(self):
            json = {}
            json['role'] = raritan.rpc.cascading.CascadeManager.Role.encode(self.role)
            json['master'] = self.master
            json['linkUnits'] = [dict(
                key = k,
                value = raritan.rpc.cascading.CascadeManager.LinkUnit.encode(v))
                for k, v in self.linkUnits.items()]
            return json

    # value object
    class RoleChangedEvent(raritan.rpc.idl.Event):
        idlType = "cascading.CascadeManager.RoleChangedEvent:1.0.0"

        def __init__(self, oldRole, newRole, master, source):
            super(raritan.rpc.cascading.CascadeManager.RoleChangedEvent, self).__init__(source)
            typecheck.is_enum(oldRole, raritan.rpc.cascading.CascadeManager.Role, AssertionError)
            typecheck.is_enum(newRole, raritan.rpc.cascading.CascadeManager.Role, AssertionError)
            typecheck.is_string(master, AssertionError)

            self.oldRole = oldRole
            self.newRole = newRole
            self.master = master

        def encode(self):
            json = super(raritan.rpc.cascading.CascadeManager.RoleChangedEvent, self).encode()
            json['oldRole'] = raritan.rpc.cascading.CascadeManager.Role.encode(self.oldRole)
            json['newRole'] = raritan.rpc.cascading.CascadeManager.Role.encode(self.newRole)
            json['master'] = self.master
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                oldRole = raritan.rpc.cascading.CascadeManager.Role.decode(json['oldRole']),
                newRole = raritan.rpc.cascading.CascadeManager.Role.decode(json['newRole']),
                master = json['master'],
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["oldRole", "newRole", "master"]
            elements = elements + super(raritan.rpc.cascading.CascadeManager.RoleChangedEvent, self).listElements()
            return elements

    # value object
    class LinkUnitAddedEvent(raritan.rpc.event.UserEvent):
        idlType = "cascading.CascadeManager.LinkUnitAddedEvent:1.0.0"

        def __init__(self, linkId, host, actUserName, actIpAddr, source):
            super(raritan.rpc.cascading.CascadeManager.LinkUnitAddedEvent, self).__init__(actUserName, actIpAddr, source)
            typecheck.is_int(linkId, AssertionError)
            typecheck.is_string(host, AssertionError)

            self.linkId = linkId
            self.host = host

        def encode(self):
            json = super(raritan.rpc.cascading.CascadeManager.LinkUnitAddedEvent, self).encode()
            json['linkId'] = self.linkId
            json['host'] = self.host
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                linkId = json['linkId'],
                host = json['host'],
                # for event.UserEvent
                actUserName = json['actUserName'],
                actIpAddr = json['actIpAddr'],
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["linkId", "host"]
            elements = elements + super(raritan.rpc.cascading.CascadeManager.LinkUnitAddedEvent, self).listElements()
            return elements

    # value object
    class LinkUnitReleasedEvent(raritan.rpc.event.UserEvent):
        idlType = "cascading.CascadeManager.LinkUnitReleasedEvent:1.0.0"

        def __init__(self, linkId, host, actUserName, actIpAddr, source):
            super(raritan.rpc.cascading.CascadeManager.LinkUnitReleasedEvent, self).__init__(actUserName, actIpAddr, source)
            typecheck.is_int(linkId, AssertionError)
            typecheck.is_string(host, AssertionError)

            self.linkId = linkId
            self.host = host

        def encode(self):
            json = super(raritan.rpc.cascading.CascadeManager.LinkUnitReleasedEvent, self).encode()
            json['linkId'] = self.linkId
            json['host'] = self.host
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                linkId = json['linkId'],
                host = json['host'],
                # for event.UserEvent
                actUserName = json['actUserName'],
                actIpAddr = json['actIpAddr'],
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["linkId", "host"]
            elements = elements + super(raritan.rpc.cascading.CascadeManager.LinkUnitReleasedEvent, self).listElements()
            return elements

    # value object
    class LinkUnitStatusChangedEvent(raritan.rpc.idl.Event):
        idlType = "cascading.CascadeManager.LinkUnitStatusChangedEvent:1.0.0"

        def __init__(self, linkId, host, oldStatus, newStatus, source):
            super(raritan.rpc.cascading.CascadeManager.LinkUnitStatusChangedEvent, self).__init__(source)
            typecheck.is_int(linkId, AssertionError)
            typecheck.is_string(host, AssertionError)
            typecheck.is_enum(oldStatus, raritan.rpc.cascading.CascadeManager.LinkUnitStatus, AssertionError)
            typecheck.is_enum(newStatus, raritan.rpc.cascading.CascadeManager.LinkUnitStatus, AssertionError)

            self.linkId = linkId
            self.host = host
            self.oldStatus = oldStatus
            self.newStatus = newStatus

        def encode(self):
            json = super(raritan.rpc.cascading.CascadeManager.LinkUnitStatusChangedEvent, self).encode()
            json['linkId'] = self.linkId
            json['host'] = self.host
            json['oldStatus'] = raritan.rpc.cascading.CascadeManager.LinkUnitStatus.encode(self.oldStatus)
            json['newStatus'] = raritan.rpc.cascading.CascadeManager.LinkUnitStatus.encode(self.newStatus)
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                linkId = json['linkId'],
                host = json['host'],
                oldStatus = raritan.rpc.cascading.CascadeManager.LinkUnitStatus.decode(json['oldStatus']),
                newStatus = raritan.rpc.cascading.CascadeManager.LinkUnitStatus.decode(json['newStatus']),
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["linkId", "host", "oldStatus", "newStatus"]
            elements = elements + super(raritan.rpc.cascading.CascadeManager.LinkUnitStatusChangedEvent, self).listElements()
            return elements

    class _getStatus(Interface.Method):
        name = 'getStatus'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = raritan.rpc.cascading.CascadeManager.Status.decode(rsp['_ret_'], agent)
            typecheck.is_struct(_ret_, raritan.rpc.cascading.CascadeManager.Status, DecodeException)
            return _ret_

    class _addLinkUnit(Interface.Method):
        name = 'addLinkUnit'

        @staticmethod
        def encode(linkId, host, login, password, newPassword):
            typecheck.is_int(linkId, AssertionError)
            typecheck.is_string(host, AssertionError)
            typecheck.is_string(login, AssertionError)
            typecheck.is_string(password, AssertionError)
            typecheck.is_string(newPassword, AssertionError)
            args = {}
            args['linkId'] = linkId
            args['host'] = host
            args['login'] = login
            args['password'] = password
            args['newPassword'] = newPassword
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _releaseLinkUnit(Interface.Method):
        name = 'releaseLinkUnit'

        @staticmethod
        def encode(linkId):
            typecheck.is_int(linkId, AssertionError)
            args = {}
            args['linkId'] = linkId
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _requestLink(Interface.Method):
        name = 'requestLink'

        @staticmethod
        def encode(token):
            typecheck.is_string(token, AssertionError)
            args = {}
            args['token'] = token
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _finalizeLink(Interface.Method):
        name = 'finalizeLink'

        @staticmethod
        def encode(token):
            typecheck.is_string(token, AssertionError)
            args = {}
            args['token'] = token
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _unlink(Interface.Method):
        name = 'unlink'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            return None
    def __init__(self, target, agent):
        super(CascadeManager, self).__init__(target, agent)
        self.getStatus = CascadeManager._getStatus(self)
        self.addLinkUnit = CascadeManager._addLinkUnit(self)
        self.releaseLinkUnit = CascadeManager._releaseLinkUnit(self)
        self.requestLink = CascadeManager._requestLink(self)
        self.finalizeLink = CascadeManager._finalizeLink(self)
        self.unlink = CascadeManager._unlink(self)



# SPDX-License-Identifier: BSD-3-Clause
#
# Copyright 2020 Raritan Inc. All rights reserved.
#
# This is an auto-generated file.

#
# Section generated by IdlC from "PortFuse.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.idl

import raritan.rpc.portsmodel


# interface
class PortFuse(Interface):
    idlType = "portsmodel.PortFuse:1.0.0"

    # enumeration
    class Status(Enumeration):
        idlType = "portsmodel.PortFuse.Status:1.0.0"
        values = ["UNKNOWN", "TRIPPED", "GOOD"]

    Status.UNKNOWN = Status(0)
    Status.TRIPPED = Status(1)
    Status.GOOD = Status(2)

    # value object
    class StatusChangedEvent(raritan.rpc.idl.Event):
        idlType = "portsmodel.PortFuse.StatusChangedEvent:1.0.0"

        def __init__(self, oldStatus, newStatus, source):
            super(raritan.rpc.portsmodel.PortFuse.StatusChangedEvent, self).__init__(source)
            typecheck.is_enum(oldStatus, raritan.rpc.portsmodel.PortFuse.Status, AssertionError)
            typecheck.is_enum(newStatus, raritan.rpc.portsmodel.PortFuse.Status, AssertionError)

            self.oldStatus = oldStatus
            self.newStatus = newStatus

        def encode(self):
            json = super(raritan.rpc.portsmodel.PortFuse.StatusChangedEvent, self).encode()
            json['oldStatus'] = raritan.rpc.portsmodel.PortFuse.Status.encode(self.oldStatus)
            json['newStatus'] = raritan.rpc.portsmodel.PortFuse.Status.encode(self.newStatus)
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                oldStatus = raritan.rpc.portsmodel.PortFuse.Status.decode(json['oldStatus']),
                newStatus = raritan.rpc.portsmodel.PortFuse.Status.decode(json['newStatus']),
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["oldStatus", "newStatus"]
            elements = elements + super(raritan.rpc.portsmodel.PortFuse.StatusChangedEvent, self).listElements()
            return elements

    class _getStatus(Interface.Method):
        name = 'getStatus'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = raritan.rpc.portsmodel.PortFuse.Status.decode(rsp['_ret_'])
            typecheck.is_enum(_ret_, raritan.rpc.portsmodel.PortFuse.Status, DecodeException)
            return _ret_

    class _reset(Interface.Method):
        name = 'reset'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            return None
    def __init__(self, target, agent):
        super(PortFuse, self).__init__(target, agent)
        self.getStatus = PortFuse._getStatus(self)
        self.reset = PortFuse._reset(self)

#
# Section generated by IdlC from "Port.idl"
#

import raritan.rpc
from raritan.rpc import Interface, Structure, ValueObject, Enumeration, typecheck, DecodeException
import raritan.rpc.idl

import raritan.rpc.portsmodel


# interface
class Port(Interface):
    idlType = "portsmodel.Port:2.0.2"

    NO_ERROR = 0

    ERR_INVALID_PARAM = 1

    ERR_DEVICE_BUSY = 2

    # enumeration
    class DetectionType(Enumeration):
        idlType = "portsmodel.Port_2_0_2.DetectionType:1.0.0"
        values = ["AUTO", "PINNED", "DISABLED"]

    DetectionType.AUTO = DetectionType(0)
    DetectionType.PINNED = DetectionType(1)
    DetectionType.DISABLED = DetectionType(2)

    # structure
    class DetectionMode(Structure):
        idlType = "portsmodel.Port_2_0_2.DetectionMode:1.0.0"
        elements = ["type", "pinnedDeviceType"]

        def __init__(self, type, pinnedDeviceType):
            typecheck.is_enum(type, raritan.rpc.portsmodel.Port.DetectionType, AssertionError)
            typecheck.is_string(pinnedDeviceType, AssertionError)

            self.type = type
            self.pinnedDeviceType = pinnedDeviceType

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                type = raritan.rpc.portsmodel.Port.DetectionType.decode(json['type']),
                pinnedDeviceType = json['pinnedDeviceType'],
            )
            return obj

        def encode(self):
            json = {}
            json['type'] = raritan.rpc.portsmodel.Port.DetectionType.encode(self.type)
            json['pinnedDeviceType'] = self.pinnedDeviceType
            return json

    # structure
    class Properties(Structure):
        idlType = "portsmodel.Port_2_0_2.Properties:1.0.0"
        elements = ["name", "label", "mode", "detectedDeviceType", "detectedDeviceName"]

        def __init__(self, name, label, mode, detectedDeviceType, detectedDeviceName):
            typecheck.is_string(name, AssertionError)
            typecheck.is_string(label, AssertionError)
            typecheck.is_struct(mode, raritan.rpc.portsmodel.Port.DetectionMode, AssertionError)
            typecheck.is_string(detectedDeviceType, AssertionError)
            typecheck.is_string(detectedDeviceName, AssertionError)

            self.name = name
            self.label = label
            self.mode = mode
            self.detectedDeviceType = detectedDeviceType
            self.detectedDeviceName = detectedDeviceName

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                name = json['name'],
                label = json['label'],
                mode = raritan.rpc.portsmodel.Port.DetectionMode.decode(json['mode'], agent),
                detectedDeviceType = json['detectedDeviceType'],
                detectedDeviceName = json['detectedDeviceName'],
            )
            return obj

        def encode(self):
            json = {}
            json['name'] = self.name
            json['label'] = self.label
            json['mode'] = raritan.rpc.portsmodel.Port.DetectionMode.encode(self.mode)
            json['detectedDeviceType'] = self.detectedDeviceType
            json['detectedDeviceName'] = self.detectedDeviceName
            return json

    # value object
    class PropertiesChangedEvent(raritan.rpc.idl.Event):
        idlType = "portsmodel.Port_2_0_2.PropertiesChangedEvent:1.0.0"

        def __init__(self, oldProperties, newProperties, source):
            super(raritan.rpc.portsmodel.Port.PropertiesChangedEvent, self).__init__(source)
            typecheck.is_struct(oldProperties, raritan.rpc.portsmodel.Port.Properties, AssertionError)
            typecheck.is_struct(newProperties, raritan.rpc.portsmodel.Port.Properties, AssertionError)

            self.oldProperties = oldProperties
            self.newProperties = newProperties

        def encode(self):
            json = super(raritan.rpc.portsmodel.Port.PropertiesChangedEvent, self).encode()
            json['oldProperties'] = raritan.rpc.portsmodel.Port.Properties.encode(self.oldProperties)
            json['newProperties'] = raritan.rpc.portsmodel.Port.Properties.encode(self.newProperties)
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                oldProperties = raritan.rpc.portsmodel.Port.Properties.decode(json['oldProperties'], agent),
                newProperties = raritan.rpc.portsmodel.Port.Properties.decode(json['newProperties'], agent),
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["oldProperties", "newProperties"]
            elements = elements + super(raritan.rpc.portsmodel.Port.PropertiesChangedEvent, self).listElements()
            return elements

    # value object
    class DeviceChangedEvent(raritan.rpc.idl.Event):
        idlType = "portsmodel.Port_2_0_2.DeviceChangedEvent:1.0.0"

        def __init__(self, oldDevice, newDevice, source):
            super(raritan.rpc.portsmodel.Port.DeviceChangedEvent, self).__init__(source)
            typecheck.is_remote_obj(oldDevice, AssertionError)
            typecheck.is_remote_obj(newDevice, AssertionError)

            self.oldDevice = oldDevice
            self.newDevice = newDevice

        def encode(self):
            json = super(raritan.rpc.portsmodel.Port.DeviceChangedEvent, self).encode()
            json['oldDevice'] = Interface.encode(self.oldDevice)
            json['newDevice'] = Interface.encode(self.newDevice)
            return json

        @classmethod
        def decode(cls, json, agent):
            obj = cls(
                oldDevice = Interface.decode(json['oldDevice'], agent),
                newDevice = Interface.decode(json['newDevice'], agent),
                # for idl.Event
                source = Interface.decode(json['source'], agent),
            )
            return obj

        def listElements(self):
            elements = ["oldDevice", "newDevice"]
            elements = elements + super(raritan.rpc.portsmodel.Port.DeviceChangedEvent, self).listElements()
            return elements

    class _getProperties(Interface.Method):
        name = 'getProperties'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = raritan.rpc.portsmodel.Port.Properties.decode(rsp['_ret_'], agent)
            typecheck.is_struct(_ret_, raritan.rpc.portsmodel.Port.Properties, DecodeException)
            return _ret_

    class _setName(Interface.Method):
        name = 'setName'

        @staticmethod
        def encode(name):
            typecheck.is_string(name, AssertionError)
            args = {}
            args['name'] = name
            return args

        @staticmethod
        def decode(rsp, agent):
            return None

    class _setDetectionMode(Interface.Method):
        name = 'setDetectionMode'

        @staticmethod
        def encode(mode):
            typecheck.is_struct(mode, raritan.rpc.portsmodel.Port.DetectionMode, AssertionError)
            args = {}
            args['mode'] = raritan.rpc.portsmodel.Port.DetectionMode.encode(mode)
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = rsp['_ret_']
            typecheck.is_int(_ret_, DecodeException)
            return _ret_

    class _getDetectableDevices(Interface.Method):
        name = 'getDetectableDevices'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = [x0 for x0 in rsp['_ret_']]
            for x0 in _ret_:
                typecheck.is_string(x0, DecodeException)
            return _ret_

    class _getDevice(Interface.Method):
        name = 'getDevice'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = Interface.decode(rsp['_ret_'], agent)
            typecheck.is_remote_obj(_ret_, DecodeException)
            return _ret_

    class _getDeviceConfig(Interface.Method):
        name = 'getDeviceConfig'

        @staticmethod
        def encode(deviceType):
            typecheck.is_string(deviceType, AssertionError)
            args = {}
            args['deviceType'] = deviceType
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = Interface.decode(rsp['_ret_'], agent)
            typecheck.is_remote_obj(_ret_, DecodeException)
            return _ret_

    class _getFuse(Interface.Method):
        name = 'getFuse'

        @staticmethod
        def encode():
            args = {}
            return args

        @staticmethod
        def decode(rsp, agent):
            _ret_ = Interface.decode(rsp['_ret_'], agent)
            typecheck.is_interface(_ret_, raritan.rpc.portsmodel.PortFuse, DecodeException)
            return _ret_
    def __init__(self, target, agent):
        super(Port, self).__init__(target, agent)
        self.getProperties = Port._getProperties(self)
        self.setName = Port._setName(self)
        self.setDetectionMode = Port._setDetectionMode(self)
        self.getDetectableDevices = Port._getDetectableDevices(self)
        self.getDevice = Port._getDevice(self)
        self.getDeviceConfig = Port._getDeviceConfig(self)
        self.getFuse = Port._getFuse(self)



# SPDX-License-Identifier: BSD-3-Clause
#
# Copyright 2010 Raritan Inc. All rights reserved.

import raritan.rpc

class Enumeration(object):
    def __init__(self, val):
        assert isinstance(val, int)
        self.val = val

    def encode(self):
        """Encodes enum value to JSON int."""
        json = self.val
        return json
 
    @classmethod
    def decode(cls, json):
        """Decodes JSON int to enum value."""
        assert isinstance(json, int)
        val = json
        assert(val >= 0)
        if (val < len(cls.values)):
            attr = cls.values[val]
            return getattr(cls, attr)
        elif hasattr(cls, '_fallback'):
            return cls._fallback
        raise KeyError(val)

    @classmethod
    def get_elements(cls):
        """Returns enum elements as instances of cls, the respective enum class."""
        return [getattr(cls, v) for v in cls.values]

    def __str__(self):
        return "%s.%s" % (raritan.rpc.TypeInfo.typeBaseName(self.idlType), self.values[self.val])

    def __repr__(self):
        return str(self)

    def __eq__(self, other):
        return self.__class__ == other.__class__ and self.val == other.val

    def __ne__(self, other):
        return not self == other

    def __hash__(self):
        return hash((self.idlType, self.val))
